@@ -57,7 +57,7 @@ namespace KMPlayer {
 
 class KMPlayerApp : public TDEMainWindow
 {
-    Q_OBJECT
+    TQ_OBJECT
   
 
 public:
