@@ -25,8 +25,8 @@
 #include <tdeparts/factory.h>
 #include <kurl.h>
 #ifdef HAVE_KOFFICE
-#include <koDocument.h>
-#include <koView.h>
+#include <KoDocument.h>
+#include <KoView.h>
 #endif //HAVE_KOFFICE
 #include <tqobject.h>
 #include <tqvaluelist.h>
@@ -39,16 +39,18 @@
 
 class TDEProcess;
 class TDEAboutData;
-class KMPlayer;
 class TDEInstance;
 class TDEConfig;
 class TQIODevice;
+namespace KMPlayer {
+    class PartBase;
+}
 
 #ifdef HAVE_KOFFICE
 class KOfficeMPlayer;
 
 class KOfficeMPlayerView : public KoView {
-    Q_OBJECT
+    TQ_OBJECT
   
 public:
     KOfficeMPlayerView (KOfficeMPlayer* part, TQWidget* parent, const char* name = 0 );
@@ -60,26 +62,27 @@ private:
 };
 
 class KOfficeMPlayer : public KoDocument {
-    Q_OBJECT
+    TQ_OBJECT
   
 public:
     KOfficeMPlayer (TQWidget *parentWidget = 0, const char *widgetName = 0, TQObject* parent = 0, const char* name = 0, bool singleViewMode = false);
-    ~KOfficeMPlayer ();
+    virtual ~KOfficeMPlayer ();
 
     virtual void paintContent (TQPainter& painter, const TQRect& rect,
             bool transparent = false, double zoomX = 1.0, double zoomY = 1.0);
-    virtual bool initDoc ();
+    virtual bool initDoc (InitDocFlags flags, TQWidget* parentWidget=0);
     virtual bool loadXML (TQIODevice *, const TQDomDocument &);
     virtual bool loadOasis (const TQDomDocument &, KoOasisStyles &, const TQDomDocument &, KoStore *);
+    virtual bool saveOasis( KoStore *store, KoXmlWriter *manifestWriter );
     virtual TQDomDocument saveXML ();
     virtual TQCString mimeType() const { return "application/x-kmplayer"; }
 
-    KMPlayer * player () const { return m_player; }
+    KMPlayer::PartBase * player () const { return m_player; }
 protected:
     virtual KoView* createViewInstance (TQWidget* parent, const char* name);
 private:
     TDEConfig * m_config;
-    KMPlayer * m_player;
+    KMPlayer::PartBase * m_player;
     KOfficeMPlayerView * m_view; 
 };
 #endif //HAVE_KOFFICE
