@@ -154,17 +154,17 @@ KDE_NO_CDTOR_EXPORT KMPlayerPart::KMPlayerPart (TQWidget * wparent, const char *
     m_sources ["hrefsource"] = (new KMPlayerHRefSource (this));
 #ifdef HAVE_NSPR
     KMPlayer::NpPlayer *npp = (KMPlayer::NpPlayer *) players () ["npp"];
-    connect (npp, TQT_SIGNAL (evaluate (const TQString &, TQString &)),
-          m_liveconnectextension, TQT_SLOT (evaluate (const TQString &, TQString &)));
-    connect (npp, TQT_SIGNAL (openUrl (const KURL &, const TQString &)),
+    connect (npp, TQ_SIGNAL (evaluate (const TQString &, TQString &)),
+          m_liveconnectextension, TQ_SLOT (evaluate (const TQString &, TQString &)));
+    connect (npp, TQ_SIGNAL (openUrl (const KURL &, const TQString &)),
             m_browserextension,
-            TQT_SLOT (slotRequestOpenURL (const KURL &, const TQString &)));
+            TQ_SLOT (slotRequestOpenURL (const KURL &, const TQString &)));
 #endif
-    /*TDEAction *playact =*/ new TDEAction(i18n("P&lay"), TQString ("media-playback-start"), TDEShortcut (), this, TQT_SLOT(play ()), actionCollection (), "play");
-    /*TDEAction *pauseact =*/ new TDEAction(i18n("&Pause"), TQString ("media-playback-pause"), TDEShortcut (), this, TQT_SLOT(pause ()), actionCollection (), "pause");
-    /*TDEAction *stopact =*/ new TDEAction(i18n("&Stop"), TQString ("media-playback-stop"), TDEShortcut (), this, TQT_SLOT(stop ()), actionCollection (), "stop");
-    new TDEAction (i18n ("Increase Volume"), TQString ("player_volume"), TDEShortcut (), this, TQT_SLOT (increaseVolume ()), actionCollection (), "edit_volume_up");
-    new TDEAction (i18n ("Decrease Volume"), TQString ("player_volume"), TDEShortcut (), this, TQT_SLOT (decreaseVolume ()), actionCollection (), "edit_volume_down");
+    /*TDEAction *playact =*/ new TDEAction(i18n("P&lay"), TQString ("media-playback-start"), TDEShortcut (), this, TQ_SLOT(play ()), actionCollection (), "play");
+    /*TDEAction *pauseact =*/ new TDEAction(i18n("&Pause"), TQString ("media-playback-pause"), TDEShortcut (), this, TQ_SLOT(pause ()), actionCollection (), "pause");
+    /*TDEAction *stopact =*/ new TDEAction(i18n("&Stop"), TQString ("media-playback-stop"), TDEShortcut (), this, TQ_SLOT(stop ()), actionCollection (), "stop");
+    new TDEAction (i18n ("Increase Volume"), TQString ("player_volume"), TDEShortcut (), this, TQ_SLOT (increaseVolume ()), actionCollection (), "edit_volume_up");
+    new TDEAction (i18n ("Decrease Volume"), TQString ("player_volume"), TDEShortcut (), this, TQ_SLOT (decreaseVolume ()), actionCollection (), "edit_volume_down");
     Source * urlsource = m_sources ["urlsource"];
     KMPlayer::ControlPanel * panel = m_view->controlPanel ();
     TQStringList::const_iterator it = args.begin ();
@@ -311,15 +311,15 @@ KDE_NO_CDTOR_EXPORT KMPlayerPart::KMPlayerPart (TQWidget * wparent, const char *
     //KParts::Part::setWidget (m_view);
     setXMLFile("kmplayerpartui.rc");
     panel->zoomMenu ()->connectItem (KMPlayer::ControlPanel::menu_zoom50,
-                                      this, TQT_SLOT (setMenuZoom (int)));
+                                      this, TQ_SLOT (setMenuZoom (int)));
     panel->zoomMenu ()->connectItem (KMPlayer::ControlPanel::menu_zoom100,
-                                      this, TQT_SLOT (setMenuZoom (int)));
+                                      this, TQ_SLOT (setMenuZoom (int)));
     panel->zoomMenu ()->connectItem (KMPlayer::ControlPanel::menu_zoom150,
-                                      this, TQT_SLOT (setMenuZoom (int)));
+                                      this, TQ_SLOT (setMenuZoom (int)));
     panel->zoomMenu ()->connectItem (KMPlayer::ControlPanel::menu_zoom200,
-                                      this, TQT_SLOT (setMenuZoom (int)));
+                                      this, TQ_SLOT (setMenuZoom (int)));
     panel->zoomMenu ()->connectItem (KMPlayer::ControlPanel::menu_zoom300,
-                                      this, TQT_SLOT (setMenuZoom (int)));
+                                      this, TQ_SLOT (setMenuZoom (int)));
 
     m_view->setNoInfoMessages (m_features != Feat_InfoPanel);
     if (m_features == Feat_InfoPanel)
@@ -344,8 +344,8 @@ KDE_NO_CDTOR_EXPORT KMPlayerPart::KMPlayerPart (TQWidget * wparent, const char *
         connectPanel (m_view->controlPanel ());
         if (m_features & Feat_StatusBar) {
             last_time_left = 0;
-            connect (this, TQT_SIGNAL (positioned (int, int)),
-                     this, TQT_SLOT (statusPosition (int, int)));
+            connect (this, TQ_SIGNAL (positioned (int, int)),
+                     this, TQ_SLOT (statusPosition (int, int)));
             m_view->statusBar ()->insertItem (TQString ("--:--"), 1, 0, true);
         }
     }
@@ -473,7 +473,7 @@ KDE_NO_EXPORT bool KMPlayerPart::openURL (const KURL & _url) {
     if (url.isEmpty ()) {
         if (!m_master && !(m_features & Feat_Viewer))
             // no master set, wait for a viewer to attach or timeout
-            TQTimer::singleShot (50, this, TQT_SLOT (waitForImageWindowTimeOut ()));
+            TQTimer::singleShot (50, this, TQ_SLOT (waitForImageWindowTimeOut ()));
         return true;
     }
     if (!m_group.isEmpty () && !(m_features & Feat_Viewer)) {
@@ -483,7 +483,7 @@ KDE_NO_EXPORT bool KMPlayerPart::openURL (const KURL & _url) {
                 i = std::find_if (++i, e, pred))
             if ((*i)->url ().isEmpty ()) // image window created w/o url
                 return (*i)->openURL (_url);
-        TQTimer::singleShot (50, this, TQT_SLOT (waitForImageWindowTimeOut ()));
+        TQTimer::singleShot (50, this, TQ_SLOT (waitForImageWindowTimeOut ()));
         //kdError () << "Not the ImageWindow and no ImageWindow found" << endl;
         return true;
     }
@@ -553,16 +553,16 @@ KDE_NO_EXPORT void KMPlayerPart::connectToPart (KMPlayerPart * m) {
     if (m_features & Feat_InfoPanel)
         m->connectInfoPanel (m_view->infoPanel ());
     connectSource (m_source, m->source ());
-    connect (m, TQT_SIGNAL (destroyed (TQObject *)),
-            this, TQT_SLOT (viewerPartDestroyed (TQObject *)));
-    connect (m, TQT_SIGNAL (processChanged (const char *)),
-            this, TQT_SLOT (viewerPartProcessChanged (const char *)));
-    connect (m, TQT_SIGNAL (sourceChanged (KMPlayer::Source *, KMPlayer::Source *)),
-            this, TQT_SLOT (viewerPartSourceChanged (KMPlayer::Source *, KMPlayer::Source *)));
+    connect (m, TQ_SIGNAL (destroyed (TQObject *)),
+            this, TQ_SLOT (viewerPartDestroyed (TQObject *)));
+    connect (m, TQ_SIGNAL (processChanged (const char *)),
+            this, TQ_SLOT (viewerPartProcessChanged (const char *)));
+    connect (m, TQ_SIGNAL (sourceChanged (KMPlayer::Source *, KMPlayer::Source *)),
+            this, TQ_SLOT (viewerPartSourceChanged (KMPlayer::Source *, KMPlayer::Source *)));
     if (m_features & Feat_StatusBar) {
         last_time_left = 0;
-        connect (m, TQT_SIGNAL (positioned (int, int)),
-                 this, TQT_SLOT (statusPosition (int, int)));
+        connect (m, TQ_SIGNAL (positioned (int, int)),
+                 this, TQ_SLOT (statusPosition (int, int)));
         m_view->statusBar ()->insertItem (TQString ("--:--"), 1, 0, true);
     }
 }
@@ -863,7 +863,7 @@ KDE_NO_CDTOR_EXPORT KMPlayerLiveConnectExtension::KMPlayerLiveConnectExtension (
     m_started (false),
     m_enablefinish (false),
     m_evaluating (false) {
-      connect (parent, TQT_SIGNAL (started (TDEIO::Job *)), this, TQT_SLOT (started ()));
+      connect (parent, TQ_SIGNAL (started (TDEIO::Job *)), this, TQ_SLOT (started ()));
 }
 
 KDE_NO_CDTOR_EXPORT KMPlayerLiveConnectExtension::~KMPlayerLiveConnectExtension() {
@@ -1153,17 +1153,17 @@ KDE_NO_EXPORT void KMPlayerHRefSource::play () {
 KDE_NO_EXPORT void KMPlayerHRefSource::activate () {
     m_player->stop ();
     if (m_finished) {
-        TQTimer::singleShot (0, this, TQT_SLOT (finished ()));
+        TQTimer::singleShot (0, this, TQ_SLOT (finished ()));
         return;
     }
     init ();
     m_player->setProcess ("mplayer");
     if (m_player->process ()->grabPicture (m_url, 0))
-        connect (m_player->process (), TQT_SIGNAL (grabReady (const TQString &)),
-                 this, TQT_SLOT (grabReady (const TQString &)));
+        connect (m_player->process (), TQ_SIGNAL (grabReady (const TQString &)),
+                 this, TQ_SLOT (grabReady (const TQString &)));
     else {
         setURL (KURL ());
-        TQTimer::singleShot (0, this, TQT_SLOT (play ()));
+        TQTimer::singleShot (0, this, TQ_SLOT (play ()));
     }
 }
 
@@ -1184,11 +1184,11 @@ KDE_NO_EXPORT void KMPlayerHRefSource::finished () {
     if (!view) return;
     if (!view->setPicture (m_grabfile)) {
         clear ();
-        TQTimer::singleShot (0, this, TQT_SLOT (play ()));
+        TQTimer::singleShot (0, this, TQ_SLOT (play ()));
         return;
     }
     if (view->viewer ())
-        connect (view, TQT_SIGNAL (pictureClicked ()), this, TQT_SLOT (play ()));
+        connect (view, TQ_SIGNAL (pictureClicked ()), this, TQ_SLOT (play ()));
 }
 
 KDE_NO_EXPORT void KMPlayerHRefSource::deactivate () {
@@ -1197,7 +1197,7 @@ KDE_NO_EXPORT void KMPlayerHRefSource::deactivate () {
     if (!view) return;
     view->setPicture (TQString ());
     if (view->viewer ())
-        disconnect (view, TQT_SIGNAL (pictureClicked ()), this, TQT_SLOT (play ()));
+        disconnect (view, TQ_SIGNAL (pictureClicked ()), this, TQ_SLOT (play ()));
 }
 
 KDE_NO_EXPORT TQString KMPlayerHRefSource::prettyName () {
