@@ -33,7 +33,7 @@ class JSCommandEntry;
  * Wrapper source for URLSource that has a HREF attribute
  */
 class KMPLAYER_NO_EXPORT KMPlayerHRefSource : public KMPlayer::Source {
-    Q_OBJECT
+    TQ_OBJECT
   
 public:
     KMPlayerHRefSource (KMPlayer::PartBase * player);
@@ -62,7 +62,7 @@ private:
  * Part notifications to hosting application
  */
 class KMPLAYER_NO_EXPORT KMPlayerBrowserExtension : public KParts::BrowserExtension {
-    Q_OBJECT
+    TQ_OBJECT
   
 public:
     KMPlayerBrowserExtension(KMPlayerPart *parent);
@@ -81,7 +81,7 @@ public slots:
  * Part javascript support
  */
 class KMPLAYER_NO_EXPORT KMPlayerLiveConnectExtension : public KParts::LiveConnectExtension {
-    Q_OBJECT
+    TQ_OBJECT
   
 public:
     KMPlayerLiveConnectExtension (KMPlayerPart * parent);
@@ -122,7 +122,7 @@ private:
  * Part that gets created when used a KPart
  */
 class KMPLAYER_NO_EXPORT KMPlayerPart : public KMPlayer::PartBase {
-    Q_OBJECT
+    TQ_OBJECT
   
     friend struct GroupPredicate;
 public:
