@@ -233,24 +233,24 @@ KDE_NO_CDTOR_EXPORT KMPlayerPrefBroadcastFormatPage::KMPlayerPrefBroadcastFormat
     TQFrame *profileframe = new TQFrame (this);
     TQGridLayout *profileslayout = new TQGridLayout (profileframe, 5, 2, 2);
     profile = new TQLineEdit ("", profileframe);
-    connect (profile, TQT_SIGNAL(textChanged (const TQString &)),
-             this, TQT_SLOT (slotTextChanged (const TQString &)));
+    connect (profile, TQ_SIGNAL(textChanged (const TQString &)),
+             this, TQ_SLOT (slotTextChanged (const TQString &)));
     profilelist = new TQListBox (profileframe);
     for (int i = 0; i < (int) profiles.size (); i++)
         profilelist->insertItem (profiles[i]->name, i);
-    connect (profilelist, TQT_SIGNAL (selected (int)),
-             this, TQT_SLOT (slotIndexChanged (int)));
-    connect (profilelist, TQT_SIGNAL (highlighted (int)),
-             this, TQT_SLOT (slotItemHighlighted (int)));
+    connect (profilelist, TQ_SIGNAL (selected (int)),
+             this, TQ_SLOT (slotIndexChanged (int)));
+    connect (profilelist, TQ_SIGNAL (highlighted (int)),
+             this, TQ_SLOT (slotItemHighlighted (int)));
     load = new TQPushButton (i18n ("Load"), profileframe);
     save = new TQPushButton (i18n ("Save"), profileframe);
     del = new TQPushButton (i18n ("Delete"), profileframe);
     load->setEnabled (false);
     save->setEnabled (false);
     del->setEnabled (false);
-    connect (load, TQT_SIGNAL (clicked ()), this, TQT_SLOT (slotLoad ()));
-    connect (save, TQT_SIGNAL (clicked ()), this, TQT_SLOT (slotSave ()));
-    connect (del, TQT_SIGNAL (clicked ()), this, TQT_SLOT (slotDelete ()));
+    connect (load, TQ_SIGNAL (clicked ()), this, TQ_SLOT (slotLoad ()));
+    connect (save, TQ_SIGNAL (clicked ()), this, TQ_SLOT (slotSave ()));
+    connect (del, TQ_SIGNAL (clicked ()), this, TQ_SLOT (slotDelete ()));
     profileslayout->addWidget (profile, 0, 0);
     profileslayout->setRowSpacing (4, 60);
     profileslayout->addMultiCellWidget (profilelist, 1, 4, 0, 0);
@@ -459,8 +459,8 @@ KDE_NO_EXPORT void KMPlayerBroadcastConfig::prefLocation (TQString & item, TQStr
 TQFrame * KMPlayerBroadcastConfig::prefPage (TQWidget * parent) {
     if (!m_configpage) {
         m_configpage = new KMPlayerPrefBroadcastFormatPage (parent, ffserversettingprofiles);
-        connect (m_configpage->startbutton, TQT_SIGNAL (clicked ()), this, TQT_SLOT (startServer ()));
-        connect (m_player, TQT_SIGNAL (sourceChanged (KMPlayer::Source *, KMPlayer::Source *)), this, TQT_SLOT (sourceChanged (KMPlayer::Source *,KMPlayer::Source *)));
+        connect (m_configpage->startbutton, TQ_SIGNAL (clicked ()), this, TQ_SLOT (startServer ()));
+        connect (m_player, TQ_SIGNAL (sourceChanged (KMPlayer::Source *, KMPlayer::Source *)), this, TQ_SLOT (sourceChanged (KMPlayer::Source *,KMPlayer::Source *)));
         m_configpage->startbutton->setEnabled
             (!m_player->source ()->videoDevice ().isEmpty ());
     }
@@ -488,8 +488,8 @@ KDE_NO_EXPORT void KMPlayerBroadcastConfig::startServer () {
     m_configpage->setCursor (TQCursor (TQt::WaitCursor));
     m_ffserver_process = new TDEProcess;
     m_ffserver_process->setUseShell (true);
-    connect (m_ffserver_process, TQT_SIGNAL (processExited (TDEProcess *)),
-             this, TQT_SLOT (processStopped (TDEProcess *)));
+    connect (m_ffserver_process, TQ_SIGNAL (processExited (TDEProcess *)),
+             this, TQ_SLOT (processStopped (TDEProcess *)));
     TQString conffile = locateLocal ("data", "kmplayer/ffserver.conf");
     const char * noaudio = m_player->source ()->audioDevice ().isEmpty () ? "NoAudio" : "";
     FFServerSetting ffs;
@@ -512,15 +512,15 @@ KDE_NO_EXPORT void KMPlayerBroadcastConfig::startServer () {
     *m_ffserver_process << "ffserver -f " << conffile;
     m_ffserver_out.truncate (0);
     connect (m_ffserver_process,
-             TQT_SIGNAL (receivedStderr (TDEProcess *, char *, int)),
-             this, TQT_SLOT (processOutput (TDEProcess *, char *, int)));
+             TQ_SIGNAL (receivedStderr (TDEProcess *, char *, int)),
+             this, TQ_SLOT (processOutput (TDEProcess *, char *, int)));
     m_ffserver_process->start (TDEProcess::NotifyOnExit, TDEProcess::Stderr);
     if (m_ffserver_process->isRunning ()) {
         m_configpage->startbutton->setText (i18n ("Stop"));
         m_configpage->serverled->setState (KLed::On);
         emit broadcastStarted ();
     }
-    TQTimer::singleShot (500, this, TQT_SLOT (startFeed ()));
+    TQTimer::singleShot (500, this, TQ_SLOT (startFeed ()));
 }
 
 KDE_NO_EXPORT void KMPlayerBroadcastConfig::stopServer () {
@@ -548,13 +548,13 @@ KDE_NO_EXPORT void KMPlayerBroadcastConfig::startFeed () {
         KMessageBox::error (m_configpage, i18n ("Failed to start ffserver.\n") + m_ffserver_out, i18n ("Error"));
         goto bail_out;
     }
-    disconnect (m_ffserver_process, TQT_SIGNAL (receivedStderr (TDEProcess *, char *, int)),
-                this, TQT_SLOT (processOutput (TDEProcess *, char *, int)));
+    disconnect (m_ffserver_process, TQ_SIGNAL (receivedStderr (TDEProcess *, char *, int)),
+                this, TQ_SLOT (processOutput (TDEProcess *, char *, int)));
     if (m_ffmpeg_process)
         m_ffmpeg_process->stop ();
     delete m_ffmpeg_process;
     m_ffmpeg_process = new KMPlayer::FFMpeg (m_player, m_player->settings ());
-    connect (m_ffmpeg_process, TQT_SIGNAL (stateChange (KMPlayer::Process::State, KMPlayer::Process::State)), this, TQT_SLOT (stateChange (KMPlayer::Process::State, KMPlayer::Process::State)));
+    connect (m_ffmpeg_process, TQ_SIGNAL (stateChange (KMPlayer::Process::State, KMPlayer::Process::State)), this, TQ_SLOT (stateChange (KMPlayer::Process::State, KMPlayer::Process::State)));
     ffurl.sprintf ("http://localhost:%d/kmplayer.ffm", m_ffserverconfig->ffserverport);
     m_ffmpeg_process->setURL (KURL(ffurl));
     if (!m_ffmpeg_process->play (m_player->source (), KMPlayer::NodePtr())) {
@@ -582,8 +582,8 @@ KDE_NO_EXPORT void KMPlayerBroadcastConfig::stateChange (KMPlayer::Process::Stat
         kdDebug () << "ffmpeg process stopped " << m_endserver << endl;
         if (m_endserver && !stopProcess (m_ffserver_process)) {
             disconnect (m_ffserver_process,
-                    TQT_SIGNAL (receivedStderr (TDEProcess *, char *, int)),
-                    this, TQT_SLOT (processOutput (TDEProcess *, char *, int)));
+                    TQ_SIGNAL (receivedStderr (TDEProcess *, char *, int)),
+                    this, TQ_SLOT (processOutput (TDEProcess *, char *, int)));
             KMessageBox::error (m_configpage, i18n ("Failed to end ffserver process."), i18n ("Error"));
             processStopped (0L);
         }
