@@ -365,13 +365,13 @@ KDE_NO_EXPORT bool Settings::createDialog () {
         if (p->supports ("urlsource"))
             configdialog->m_SourcePageURL->backend->insertItem (p->menuName ().remove (TQChar ('&')), id++);
     }
-    connect (configdialog, TQT_SIGNAL (okClicked ()),
-            this, TQT_SLOT (okPressed ()));
-    connect (configdialog, TQT_SIGNAL (applyClicked ()),
-            this, TQT_SLOT (okPressed ()));
+    connect (configdialog, TQ_SIGNAL (okClicked ()),
+            this, TQ_SLOT (okPressed ()));
+    connect (configdialog, TQ_SIGNAL (applyClicked ()),
+            this, TQ_SLOT (okPressed ()));
     if (TDEApplication::kApplication())
-        connect (configdialog, TQT_SIGNAL (helpClicked ()),
-                this, TQT_SLOT (getHelp ()));
+        connect (configdialog, TQ_SIGNAL (helpClicked ()),
+                this, TQ_SLOT (getHelp ()));
     return true;
 }
 
