@@ -372,7 +372,7 @@ KDE_NO_CDTOR_EXPORT ControlPanel::ControlPanel(TQWidget * parent, View * view)
     m_buttons[button_stop]->setToggleButton (true);
     m_buttons[button_record]->setToggleButton (true);
     m_buttons[button_broadcast]->setToggleButton (true);
-    m_posSlider = new TQSlider (0, 100, 1, 0, Qt::Horizontal, this);
+    m_posSlider = new TQSlider (0, 100, 1, 0, TQt::Horizontal, this);
     m_posSlider->setEnabled (false);
     m_buttonbox->addWidget (m_posSlider);
     setupPositionSlider (true);
@@ -405,39 +405,39 @@ KDE_NO_CDTOR_EXPORT ControlPanel::ControlPanel(TQWidget * parent, View * view)
     m_languageMenu->insertItem (TDEGlobal::iconLoader ()->loadIconSet (TQString ("view_text"), TDEIcon::Small, 0, true), i18n ("&Subtitles"), m_subtitleMenu);
     TQLabel * label = new TQLabel (i18n ("Contrast:"), m_colorMenu);
     m_colorMenu->insertItem (label);
-    m_contrastSlider = new TQSlider (-100, 100, 10, 0, Qt::Horizontal, m_colorMenu);
+    m_contrastSlider = new TQSlider (-100, 100, 10, 0, TQt::Horizontal, m_colorMenu);
     m_colorMenu->insertItem (m_contrastSlider);
     label = new TQLabel (i18n ("Brightness:"), m_colorMenu);
     m_colorMenu->insertItem (label);
-    m_brightnessSlider = new TQSlider (-100, 100, 10, 0, Qt::Horizontal, m_colorMenu);
+    m_brightnessSlider = new TQSlider (-100, 100, 10, 0, TQt::Horizontal, m_colorMenu);
     m_colorMenu->insertItem (m_brightnessSlider);
     label = new TQLabel (i18n ("Hue:"), m_colorMenu);
     m_colorMenu->insertItem (label);
-    m_hueSlider = new TQSlider (-100, 100, 10, 0, Qt::Horizontal, m_colorMenu);
+    m_hueSlider = new TQSlider (-100, 100, 10, 0, TQt::Horizontal, m_colorMenu);
     m_colorMenu->insertItem (m_hueSlider);
     label = new TQLabel (i18n ("Saturation:"), m_colorMenu);
     m_colorMenu->insertItem (label);
-    m_saturationSlider = new TQSlider (-100, 100, 10, 0, Qt::Horizontal, m_colorMenu);
+    m_saturationSlider = new TQSlider (-100, 100, 10, 0, TQt::Horizontal, m_colorMenu);
     m_colorMenu->insertItem (m_saturationSlider);
     m_popupMenu->insertItem (TDEGlobal::iconLoader ()->loadIconSet (TQString ("colorize"), TDEIcon::Small, 0, true), i18n ("Co&lors"), m_colorMenu);
     m_popupMenu->insertSeparator ();
     m_popupMenu->insertItem (TDEGlobal::iconLoader ()->loadIconSet (TQString ("configure"), TDEIcon::Small, 0, true), i18n ("&Configure KMPlayer..."), menu_config);
     setAutoControls (true);
-    connect (m_buttons [button_config], TQT_SIGNAL (clicked ()),
-            this, TQT_SLOT (buttonClicked ()));
-    connect (m_buttons [button_language], TQT_SIGNAL (clicked ()),
-            this, TQT_SLOT (buttonClicked ()));
-    connect (m_buttons [button_config], TQT_SIGNAL (mouseEntered ()),
-             this, TQT_SLOT (buttonMouseEntered ()));
-    connect (m_buttons [button_language], TQT_SIGNAL (mouseEntered ()),
-             this, TQT_SLOT (buttonMouseEntered ()));
-    connect (m_popupMenu, TQT_SIGNAL (mouseLeft ()), this, TQT_SLOT (menuMouseLeft ()));
-    connect (m_playerMenu, TQT_SIGNAL (mouseLeft ()), this, TQT_SLOT(menuMouseLeft ()));
-    connect (m_zoomMenu, TQT_SIGNAL (mouseLeft ()), this, TQT_SLOT (menuMouseLeft ()));
-    connect (m_colorMenu, TQT_SIGNAL (mouseLeft ()), this, TQT_SLOT (menuMouseLeft ()));
-    connect (m_languageMenu, TQT_SIGNAL(mouseLeft ()), this, TQT_SLOT(menuMouseLeft()));
-    connect (m_subtitleMenu, TQT_SIGNAL(mouseLeft ()), this, TQT_SLOT(menuMouseLeft()));
-    connect (m_audioMenu, TQT_SIGNAL (mouseLeft ()), this, TQT_SLOT (menuMouseLeft ()));
+    connect (m_buttons [button_config], TQ_SIGNAL (clicked ()),
+            this, TQ_SLOT (buttonClicked ()));
+    connect (m_buttons [button_language], TQ_SIGNAL (clicked ()),
+            this, TQ_SLOT (buttonClicked ()));
+    connect (m_buttons [button_config], TQ_SIGNAL (mouseEntered ()),
+             this, TQ_SLOT (buttonMouseEntered ()));
+    connect (m_buttons [button_language], TQ_SIGNAL (mouseEntered ()),
+             this, TQ_SLOT (buttonMouseEntered ()));
+    connect (m_popupMenu, TQ_SIGNAL (mouseLeft ()), this, TQ_SLOT (menuMouseLeft ()));
+    connect (m_playerMenu, TQ_SIGNAL (mouseLeft ()), this, TQ_SLOT(menuMouseLeft ()));
+    connect (m_zoomMenu, TQ_SIGNAL (mouseLeft ()), this, TQ_SLOT (menuMouseLeft ()));
+    connect (m_colorMenu, TQ_SIGNAL (mouseLeft ()), this, TQ_SLOT (menuMouseLeft ()));
+    connect (m_languageMenu, TQ_SIGNAL(mouseLeft ()), this, TQ_SLOT(menuMouseLeft()));
+    connect (m_subtitleMenu, TQ_SIGNAL(mouseLeft ()), this, TQ_SLOT(menuMouseLeft()));
+    connect (m_audioMenu, TQ_SIGNAL (mouseLeft ()), this, TQ_SLOT (menuMouseLeft ()));
 }
 
 KDE_NO_EXPORT void ControlPanel::setPalette (const TQPalette & pal) {
