@@ -42,7 +42,7 @@ class View;
  * A button from the controlpanel
  */
 class KMPLAYER_NO_EXPORT KMPlayerMenuButton : public TQPushButton {
-    Q_OBJECT
+    TQ_OBJECT
   
 public:
     KMPlayerMenuButton (TQWidget *, TQBoxLayout *, const char **, int = 0);
@@ -57,7 +57,7 @@ protected:
  * The pop down menu from the controlpanel
  */
 class KMPLAYER_EXPORT KMPlayerPopupMenu : public TDEPopupMenu {
-    Q_OBJECT
+    TQ_OBJECT
   
 public:
     KMPlayerPopupMenu (TQWidget *);
@@ -72,7 +72,7 @@ protected:
  * The volume bar from the controlpanel
  */
 class KMPLAYER_EXPORT VolumeBar : public TQWidget {
-    Q_OBJECT
+    TQ_OBJECT
   
 public:
     VolumeBar (TQWidget * parent, View * view);
@@ -95,7 +95,7 @@ private:
  * The controlpanel GUI
  */
 class KMPLAYER_EXPORT ControlPanel : public TQWidget {
-    Q_OBJECT
+    TQ_OBJECT
   
 public:
     enum MenuID {
