@@ -191,7 +191,7 @@ void Process::setState (State newstate) {
         m_old_state = m_state;
         m_state = newstate;
         if (need_timer && m_source)
-            TQTimer::singleShot (0, this, TQT_SLOT (rescheduledStateChanged ()));
+            TQTimer::singleShot (0, this, TQ_SLOT (rescheduledStateChanged ()));
     }
 }
 
@@ -213,7 +213,7 @@ bool Process::play (Source * src, NodePtr _mrl) {
         return deMediafiedPlay ();
     m_url = url;
     m_job = TDEIO::stat (m_url, false);
-    connect(m_job, TQT_SIGNAL (result(TDEIO::Job *)), this, TQT_SLOT(result(TDEIO::Job *)));
+    connect(m_job, TQ_SIGNAL (result(TDEIO::Job *)), this, TQ_SLOT(result(TDEIO::Job *)));
     return true;
 #else
     return deMediafiedPlay ();
@@ -281,10 +281,10 @@ KDE_NO_EXPORT void MPlayerBase::initProcess (Viewer * viewer) {
         if (KProtocolManager::useProxy () && proxyForURL (url, proxy_url))
             m_process->setEnvironment("http_proxy", proxy_url);
     }
-    connect (m_process, TQT_SIGNAL (wroteStdin (TDEProcess *)),
-            this, TQT_SLOT (dataWritten (TDEProcess *)));
-    connect (m_process, TQT_SIGNAL (processExited (TDEProcess *)),
-            this, TQT_SLOT (processStopped (TDEProcess *)));
+    connect (m_process, TQ_SIGNAL (wroteStdin (TDEProcess *)),
+            this, TQ_SLOT (dataWritten (TDEProcess *)));
+    connect (m_process, TQ_SIGNAL (processExited (TDEProcess *)),
+            this, TQ_SLOT (processStopped (TDEProcess *)));
 }
 
 KDE_NO_EXPORT bool MPlayerBase::sendCommand (const TQString & cmd) {
@@ -309,8 +309,8 @@ KDE_NO_EXPORT bool MPlayerBase::stop () {
 KDE_NO_EXPORT bool MPlayerBase::quit () {
     if (playing ()) {
         stop ();
-        disconnect (m_process, TQT_SIGNAL (processExited (TDEProcess *)),
-                this, TQT_SLOT (processStopped (TDEProcess *)));
+        disconnect (m_process, TQ_SIGNAL (processExited (TDEProcess *)),
+                this, TQ_SLOT (processStopped (TDEProcess *)));
         if (!m_use_slave) {
             void (*oldhandler)(int) = signal(SIGTERM, SIG_IGN);
             ::kill (-1 * ::getpid (), SIGTERM);
@@ -523,10 +523,10 @@ KDE_NO_EXPORT bool MPlayer::brightness (int val, bool /*absolute*/) {
 bool MPlayer::run (const char * args, const char * pipe) {
     //m_view->consoleOutput ()->clear ();
     m_process_output = TQString ();
-    connect (m_process, TQT_SIGNAL (receivedStdout (TDEProcess *, char *, int)),
-            this, TQT_SLOT (processOutput (TDEProcess *, char *, int)));
-    connect (m_process, TQT_SIGNAL (receivedStderr (TDEProcess *, char *, int)),
-            this, TQT_SLOT (processOutput (TDEProcess *, char *, int)));
+    connect (m_process, TQ_SIGNAL (receivedStdout (TDEProcess *, char *, int)),
+            this, TQ_SLOT (processOutput (TDEProcess *, char *, int)));
+    connect (m_process, TQ_SIGNAL (receivedStderr (TDEProcess *, char *, int)),
+            this, TQ_SLOT (processOutput (TDEProcess *, char *, int)));
     m_use_slave = !(pipe && pipe[0]);
     if (!m_use_slave) {
         fprintf (stderr, "%s | ", pipe);
@@ -1427,12 +1427,12 @@ TQString CallbackProcess::dcopName () {
 
 void CallbackProcess::initProcess (Viewer * viewer) {
     Process::initProcess (viewer);
-    connect (m_process, TQT_SIGNAL (processExited (TDEProcess *)),
-            this, TQT_SLOT (processStopped (TDEProcess *)));
-    connect (m_process, TQT_SIGNAL (receivedStdout (TDEProcess *, char *, int)),
-            this, TQT_SLOT (processOutput (TDEProcess *, char *, int)));
-    connect (m_process, TQT_SIGNAL (receivedStderr (TDEProcess *, char *, int)),
-            this, TQT_SLOT (processOutput (TDEProcess *, char *, int)));
+    connect (m_process, TQ_SIGNAL (processExited (TDEProcess *)),
+            this, TQ_SLOT (processStopped (TDEProcess *)));
+    connect (m_process, TQ_SIGNAL (receivedStdout (TDEProcess *, char *, int)),
+            this, TQ_SLOT (processOutput (TDEProcess *, char *, int)));
+    connect (m_process, TQ_SIGNAL (receivedStderr (TDEProcess *, char *, int)),
+            this, TQ_SLOT (processOutput (TDEProcess *, char *, int)));
 }
 
 KDE_NO_EXPORT void CallbackProcess::processOutput (TDEProcess *, char * str, int slen) {
@@ -1508,7 +1508,7 @@ TQWidget * TypeNode::createWidget (TQWidget * parent) {
     if (!strcmp (ctype, "range")) {
         w = new TQSlider (getAttribute (TQString ("START")).toInt (),
                 getAttribute (StringPool::attr_end).toInt (),
-                1, value.toInt (), Qt::Horizontal, parent);
+                1, value.toInt (), TQt::Horizontal, parent);
     } else if (!strcmp (ctype, "num") || !strcmp (ctype,  "string")) {
         w = new TQLineEdit (value, parent);
     } else if (!strcmp (ctype, "bool")) {
@@ -1822,8 +1822,8 @@ KDE_NO_EXPORT void FFMpeg::init () {
 bool FFMpeg::deMediafiedPlay () {
     initProcess (viewer ());
     KURL url (m_url);
-    connect (m_process, TQT_SIGNAL (processExited (TDEProcess *)),
-            this, TQT_SLOT (processStopped (TDEProcess *)));
+    connect (m_process, TQ_SIGNAL (processExited (TDEProcess *)),
+            this, TQ_SLOT (processStopped (TDEProcess *)));
     TQString outurl = TQString (TQFile::encodeName (m_recordurl.isLocalFile () ? getPath (m_recordurl) : m_recordurl.url ()));
     if (m_recordurl.isLocalFile ())
         TQFile (outurl).remove ();
@@ -2033,16 +2033,16 @@ KDE_NO_EXPORT void NpStream::open () {
     } else {
         job = TDEIO::get (url, false, false);
         job->addMetaData ("errorPage", "false");
-        connect (job, TQT_SIGNAL (data (TDEIO::Job *, const TQByteArray &)),
-                this, TQT_SLOT (slotData (TDEIO::Job *, const TQByteArray &)));
-        connect (job, TQT_SIGNAL (result (TDEIO::Job *)),
-                this, TQT_SLOT (slotResult (TDEIO::Job *)));
-        connect (job, TQT_SIGNAL (redirection (TDEIO::Job *, const KURL &)),
-                this, TQT_SLOT (redirection (TDEIO::Job *, const KURL &)));
-        connect (job, TQT_SIGNAL (mimetype (TDEIO::Job *, const TQString &)),
-                TQT_SLOT (slotMimetype (TDEIO::Job *, const TQString &)));
-        connect (job, TQT_SIGNAL (totalSize (TDEIO::Job *, TDEIO::filesize_t)),
-                TQT_SLOT (slotTotalSize (TDEIO::Job *, TDEIO::filesize_t)));
+        connect (job, TQ_SIGNAL (data (TDEIO::Job *, const TQByteArray &)),
+                this, TQ_SLOT (slotData (TDEIO::Job *, const TQByteArray &)));
+        connect (job, TQ_SIGNAL (result (TDEIO::Job *)),
+                this, TQ_SLOT (slotResult (TDEIO::Job *)));
+        connect (job, TQ_SIGNAL (redirection (TDEIO::Job *, const KURL &)),
+                this, TQ_SLOT (redirection (TDEIO::Job *, const KURL &)));
+        connect (job, TQ_SIGNAL (mimetype (TDEIO::Job *, const TQString &)),
+                TQ_SLOT (slotMimetype (TDEIO::Job *, const TQString &)));
+        connect (job, TQ_SIGNAL (totalSize (TDEIO::Job *, TDEIO::filesize_t)),
+                TQ_SLOT (slotTotalSize (TDEIO::Job *, TDEIO::filesize_t)));
     }
 }
 
@@ -2116,14 +2116,14 @@ KDE_NO_EXPORT void NpPlayer::init () {
 
 KDE_NO_EXPORT void NpPlayer::initProcess (Viewer * viewer) {
     Process::initProcess (viewer);
-    connect (m_process, TQT_SIGNAL (processExited (TDEProcess *)),
-            this, TQT_SLOT (processStopped (TDEProcess *)));
-    connect (m_process, TQT_SIGNAL (receivedStdout (TDEProcess *, char *, int)),
-            this, TQT_SLOT (processOutput (TDEProcess *, char *, int)));
-    connect (m_process, TQT_SIGNAL (receivedStderr (TDEProcess *, char *, int)),
-            this, TQT_SLOT (processOutput (TDEProcess *, char *, int)));
-    connect (m_process, TQT_SIGNAL (wroteStdin (TDEProcess *)),
-            this, TQT_SLOT (wroteStdin (TDEProcess *)));
+    connect (m_process, TQ_SIGNAL (processExited (TDEProcess *)),
+            this, TQ_SLOT (processStopped (TDEProcess *)));
+    connect (m_process, TQ_SIGNAL (receivedStdout (TDEProcess *, char *, int)),
+            this, TQ_SLOT (processOutput (TDEProcess *, char *, int)));
+    connect (m_process, TQ_SIGNAL (receivedStderr (TDEProcess *, char *, int)),
+            this, TQ_SLOT (processOutput (TDEProcess *, char *, int)));
+    connect (m_process, TQ_SIGNAL (wroteStdin (TDEProcess *)),
+            this, TQ_SLOT (wroteStdin (TDEProcess *)));
     if (!dbus_static)
         dbus_static = dbus_static_deleter.setObject (new DBusStatic ());
     if (iface.isEmpty ()) {
@@ -2316,8 +2316,8 @@ void NpPlayer::requestStream (const TQString &path, const TQString & url, const
             sendFinish (sid, 0, NpStream::BecauseDone);
         } else {
             NpStream * ns = new NpStream (this, sid, uri);
-            connect (ns, TQT_SIGNAL (stateChanged ()),
-                    this, TQT_SLOT (streamStateChanged ()));
+            connect (ns, TQ_SIGNAL (stateChanged ()),
+                    this, TQ_SLOT (streamStateChanged ()));
             streams[sid] = ns;
             if (url != uri.url ())
                 streamRedirected (sid, uri.url ());
@@ -2453,8 +2453,8 @@ KDE_NO_EXPORT void NpPlayer::processStreams () {
             ns->open ();
             write_in_progress = false;
             if (ns->job) {
-                connect (ns, TQT_SIGNAL (redirected (TQ_UINT32, const KURL&)),
-                        this, TQT_SLOT (streamRedirected (TQ_UINT32, const KURL&)));
+                connect (ns, TQ_SIGNAL (redirected (TQ_UINT32, const KURL&)),
+                        this, TQ_SLOT (streamRedirected (TQ_UINT32, const KURL&)));
                 active_count++;
             }
         }
