@@ -54,7 +54,7 @@ class Backend_stub;
  * Base class for all backend processes
  */
 class KMPLAYER_EXPORT Process : public TQObject {
-    Q_OBJECT
+    TQ_OBJECT
   
 public:
     enum State {
@@ -119,7 +119,7 @@ private:
  * Base class for all MPlayer based processes
  */
 class MPlayerBase : public Process {
-    Q_OBJECT
+    TQ_OBJECT
   
 public:
     MPlayerBase (TQObject * parent, Settings * settings, const char * n);
@@ -145,7 +145,7 @@ class MPlayerPreferencesFrame;
  * MPlayer process
  */
 class KDE_EXPORT MPlayer : public MPlayerBase {
-    Q_OBJECT
+    TQ_OBJECT
   
 public:
     MPlayer (TQObject * parent, Settings * settings);
@@ -236,7 +236,7 @@ protected:
  * MEncoder recorder
  */
 class MEncoder : public MPlayerBase, public Recorder {
-    Q_OBJECT
+    TQ_OBJECT
   
 public:
     MEncoder (TQObject * parent, Settings * settings);
@@ -252,7 +252,7 @@ public slots:
  */
 class KMPLAYER_NO_EXPORT MPlayerDumpstream
   : public MPlayerBase, public Recorder {
-    Q_OBJECT
+    TQ_OBJECT
   
 public:
     MPlayerDumpstream (TQObject * parent, Settings * settings);
@@ -270,7 +270,7 @@ class XMLPreferencesFrame;
  * Base class for all backend processes having the KMPlayer::Backend interface
  */
 class KMPLAYER_EXPORT CallbackProcess : public Process {
-    Q_OBJECT
+    TQ_OBJECT
   
     friend class Callback;
 public:
@@ -377,7 +377,7 @@ private:
  * Xine backend process
  */
 class KMPLAYER_NO_EXPORT Xine : public CallbackProcess, public Recorder {
-    Q_OBJECT
+    TQ_OBJECT
   
 public:
     Xine (TQObject * parent, Settings * settings);
@@ -390,7 +390,7 @@ public slots:
  * GStreamer backend process
  */
 class KMPLAYER_NO_EXPORT GStreamer : public CallbackProcess {
-    Q_OBJECT
+    TQ_OBJECT
   
 public:
     GStreamer (TQObject * parent, Settings * settings);
@@ -403,7 +403,7 @@ public slots:
  * ffmpeg backend recorder
  */
 class KMPLAYER_EXPORT FFMpeg : public Process, public Recorder {
-    Q_OBJECT
+    TQ_OBJECT
   
 public:
     FFMpeg (TQObject * parent, Settings * settings);
@@ -422,7 +422,7 @@ private slots:
  */
 
 class KMPLAYER_NO_EXPORT NpStream : public TQObject {
-    Q_OBJECT
+    TQ_OBJECT
   
 public:
     enum Reason {
@@ -457,7 +457,7 @@ private slots:
 };
 
 class KMPLAYER_NO_EXPORT NpPlayer : public Process {
-    Q_OBJECT
+    TQ_OBJECT
   
 public:
     NpPlayer (TQObject * parent, Settings * settings, const TQString & srv);
