@@ -116,7 +116,7 @@ KDE_NO_CDTOR_EXPORT TVDevicePage::TVDevicePage (TQWidget *parent, KMPlayer::Node
         inputsTab->addTab (widget, input->mrl ()->pretty_name);
     }
     TQPushButton * delButton = new TQPushButton (i18n ("Delete"), this);
-    connect (delButton, TQT_SIGNAL (clicked ()), this, TQT_SLOT (slotDelete ()));
+    connect (delButton, TQ_SIGNAL (clicked ()), this, TQ_SLOT (slotDelete ()));
     gridlayout->addWidget (audioLabel, 0, 0);
     gridlayout->addMultiCellWidget (audiodevice, 0, 0, 1, 3);
     gridlayout->addWidget (nameLabel, 1, 0);
@@ -298,14 +298,14 @@ KDE_NO_EXPORT void TVDevice::updateDevicePage () {
         bool ok;
         if (input->getAttribute ("tuner").toInt (&ok) && ok) {
             TQWidget * widget = device_page->inputsTab->page (i);
-            TQTable * table = static_cast <TQTable *> (TQT_TQWIDGET(widget->child ("PageTVChannels", "TQTable")));
+            TQTable * table = static_cast <TQTable *>(widget->child ("PageTVChannels", "TQTable"));
             if (table) {
                 input->clearChildren ();
                 for (int j = 0; j<table->numRows() && table->item (j, 1); ++j) {
                     input->appendChild (new TVChannel (m_doc, table->item (j, 0)->text (), table->item (j, 1)->text ().toDouble ()));
                 }
             }
-            TQComboBox * norms = static_cast <TQComboBox *> (TQT_TQWIDGET(widget->child ("PageTVNorm", "TQComboBox")));
+            TQComboBox * norms = static_cast <TQComboBox *>(widget->child ("PageTVNorm", "TQComboBox"));
             if (norms) {
                 input->setAttribute ("norm", norms->currentText ());
             }
@@ -345,7 +345,7 @@ KDE_NO_CDTOR_EXPORT KMPlayerTVSource::KMPlayerTVSource (KMPlayerApp * a, TQPopup
     : KMPlayerMenuSource (i18n ("TV"), a, m, "tvsource"), m_configpage (0L), scanner (0L), config_read (false) {
     m_url = "tv://";
     m_menu->insertTearOffHandle ();
-    connect (m_menu, TQT_SIGNAL (aboutToShow ()), this, TQT_SLOT (menuAboutToShow ()));
+    connect (m_menu, TQ_SIGNAL (aboutToShow ()), this, TQ_SLOT (menuAboutToShow ()));
     m_document = new TVDocument (this);
     m_player->settings ()->addPage (this);
     tree_id = static_cast <KMPlayer::View*>(m_player->view ())->playList ()->addTree (m_document, "tvsource", "tv", KMPlayer::PlayListView::TreeEdit | KMPlayer::PlayListView::Moveable | KMPlayer::PlayListView::Deleteable);
@@ -379,7 +379,7 @@ KDE_NO_EXPORT void KMPlayerTVSource::activate () {
     if (m_cur_tvdevice) {
         TQString playback = static_cast <KMPlayer::Element *> (m_cur_tvdevice.ptr ())->getAttribute (TQString::fromLatin1 ("playback"));
         if (playback.isEmpty () || playback.toInt ())
-            TQTimer::singleShot (0, m_player, TQT_SLOT (play ()));
+            TQTimer::singleShot (0, m_player, TQ_SLOT (play ()));
     }
 }
 /* TODO: playback by
@@ -397,7 +397,7 @@ KDE_NO_EXPORT void KMPlayerTVSource::buildMenu () {
     int counter = 0;
     for (KMPlayer::NodePtr dp = m_document->firstChild (); dp; dp = dp->nextSibling ())
         if (dp->id == id_node_tv_device)
-            m_menu->insertItem (KMPlayer::convertNode <TVDevice> (dp)->pretty_name, this, TQT_SLOT (menuClicked (int)), 0, counter++);
+            m_menu->insertItem (KMPlayer::convertNode <TVDevice> (dp)->pretty_name, this, TQ_SLOT (menuClicked (int)), 0, counter++);
 }
 
 KDE_NO_EXPORT void KMPlayerTVSource::menuAboutToShow () {
@@ -486,7 +486,7 @@ KDE_NO_EXPORT void KMPlayerTVSource::buildArguments () {
 KDE_NO_EXPORT void KMPlayerTVSource::playCurrent () {
     buildArguments ();
     if (m_app->broadcasting ())
-        TQTimer::singleShot (0, m_app->broadcastConfig (), TQT_SLOT (startFeed ()));
+        TQTimer::singleShot (0, m_app->broadcastConfig (), TQ_SLOT (startFeed ()));
     else
         KMPlayer::Source::playCurrent ();
 }
@@ -575,7 +575,7 @@ KDE_NO_EXPORT TQFrame * KMPlayerTVSource::prefPage (TQWidget * parent) {
     if (!m_configpage) {
         m_configpage = new KMPlayerPrefSourcePageTV (parent, this);
         scanner = new TVDeviceScannerSource (this);
-        connect (m_configpage->scan, TQT_SIGNAL(clicked()), this, TQT_SLOT(slotScan()));
+        connect (m_configpage->scan, TQ_SIGNAL(clicked()), this, TQ_SLOT(slotScan()));
     }
     return m_configpage;
 }
@@ -592,16 +592,16 @@ KDE_NO_EXPORT void KMPlayerTVSource::slotScan () {
     TQString devstr = m_configpage->device->lineEdit()->text ();
     if (!hasTVDevice(m_document, devstr)) {
         scanner->scan (devstr, m_configpage->driver->text());
-        connect (scanner, TQT_SIGNAL (scanFinished (TVDevice *)),
-                this, TQT_SLOT (slotScanFinished (TVDevice *)));
+        connect (scanner, TQ_SIGNAL (scanFinished (TVDevice *)),
+                this, TQ_SLOT (slotScanFinished (TVDevice *)));
     } else
         KMessageBox::error (m_configpage, i18n ("Device already present."),
                 i18n ("Error"));
 }
 
 KDE_NO_EXPORT void KMPlayerTVSource::slotScanFinished (TVDevice * tvdevice) {
-    disconnect (scanner, TQT_SIGNAL (scanFinished (TVDevice *)),
-                this, TQT_SLOT (slotScanFinished (TVDevice *)));
+    disconnect (scanner, TQ_SIGNAL (scanFinished (TVDevice *)),
+                this, TQ_SLOT (slotScanFinished (TVDevice *)));
     if (tvdevice) {
         tvdevice->zombie = false;
         addTVDevicePage (tvdevice, true);
@@ -614,8 +614,8 @@ KDE_NO_EXPORT void KMPlayerTVSource::addTVDevicePage(TVDevice *dev, bool show) {
         dev->device_page->deleteLater ();
     dev->device_page = new TVDevicePage (m_configpage->notebook, dev);
     m_configpage->notebook->insertTab (dev->device_page, dev->pretty_name);
-    connect (dev->device_page, TQT_SIGNAL (deleted (TVDevicePage *)),
-             this, TQT_SLOT (slotDeviceDeleted (TVDevicePage *)));
+    connect (dev->device_page, TQ_SIGNAL (deleted (TVDevicePage *)),
+             this, TQ_SLOT (slotDeviceDeleted (TVDevicePage *)));
     if (show)
         m_configpage->notebook->setCurrentPage (m_configpage->notebook->count ()-1);
 }
