@@ -96,7 +96,7 @@ KDE_NO_CDTOR_EXPORT KMPlayerPrefSourcePageVDR::KMPlayerPrefSourcePageVDR (TQWidg
     gridlayout->addWidget (tcp_port, 0, 1);
     layout->addWidget (xv_port);
     layout->addLayout (gridlayout);
-    scale = new TQButtonGroup (2, Qt::Vertical, i18n ("Scale"), this);
+    scale = new TQButtonGroup (2, TQt::Vertical, i18n ("Scale"), this);
     new TQRadioButton (i18n ("4:3"), scale);
     new TQRadioButton (i18n ("16:9"), scale);
     TQWhatsThis::add (scale, i18n ("Aspects to use when viewing VDR"));
@@ -142,10 +142,10 @@ KDE_NO_CDTOR_EXPORT KMPlayerVDRSource::KMPlayerVDRSource (KMPlayerApp * app)
    m_stored_volume (0) {
     memset (m_actions, 0, sizeof (TDEAction *) * int (act_last));
     m_player->settings ()->addPage (this);
-    connect (m_socket, TQT_SIGNAL (connectionClosed()), this, TQT_SLOT(disconnected()));
-    connect (m_socket, TQT_SIGNAL (connected ()), this, TQT_SLOT (connected ()));
-    connect (m_socket, TQT_SIGNAL (readyRead ()), this, TQT_SLOT (readyRead ()));
-    connect (m_socket, TQT_SIGNAL (error (int)), this, TQT_SLOT (socketError (int)));
+    connect (m_socket, TQ_SIGNAL (connectionClosed()), this, TQ_SLOT(disconnected()));
+    connect (m_socket, TQ_SIGNAL (connected ()), this, TQ_SLOT (connected ()));
+    connect (m_socket, TQ_SIGNAL (readyRead ()), this, TQ_SLOT (readyRead ()));
+    connect (m_socket, TQ_SIGNAL (error (int)), this, TQ_SLOT (socketError (int)));
 }
 
 KDE_NO_CDTOR_EXPORT KMPlayerVDRSource::~KMPlayerVDRSource () {}
@@ -174,8 +174,8 @@ KDE_NO_EXPORT TQString KMPlayerVDRSource::prettyName () {
 
 KDE_NO_EXPORT void KMPlayerVDRSource::activate () {
     last_channel = 0;
-    connect (this, TQT_SIGNAL (startPlaying ()), this, TQT_SLOT (processStarted()));
-    connect (this, TQT_SIGNAL (stopPlaying ()), this, TQT_SLOT (processStopped ()));
+    connect (this, TQ_SIGNAL (startPlaying ()), this, TQ_SLOT (processStarted()));
+    connect (this, TQ_SIGNAL (stopPlaying ()), this, TQ_SLOT (processStopped ()));
     KMPlayer::ControlPanel * panel = m_app->view()->controlPanel ();
     panel->button (KMPlayer::ControlPanel::button_red)->show ();
     panel->button (KMPlayer::ControlPanel::button_green)->show ();
@@ -183,29 +183,29 @@ KDE_NO_EXPORT void KMPlayerVDRSource::activate () {
     panel->button (KMPlayer::ControlPanel::button_blue)->show ();
     panel->button (KMPlayer::ControlPanel::button_pause)->hide ();
     panel->button (KMPlayer::ControlPanel::button_record)->hide ();
-    connect (panel->volumeBar (), TQT_SIGNAL (volumeChanged (int)), this, TQT_SLOT (volumeChanged (int)));
-    connect (panel->button (KMPlayer::ControlPanel::button_red), TQT_SIGNAL (clicked ()), this, TQT_SLOT (keyRed ()));
-    connect (panel->button (KMPlayer::ControlPanel::button_green), TQT_SIGNAL (clicked ()), this, TQT_SLOT (keyGreen ()));
-    connect (panel->button (KMPlayer::ControlPanel::button_yellow), TQT_SIGNAL (clicked ()), this, TQT_SLOT (keyYellow ()));
-    connect (panel->button (KMPlayer::ControlPanel::button_blue), TQT_SIGNAL (clicked ()), this, TQT_SLOT (keyBlue ()));
+    connect (panel->volumeBar (), TQ_SIGNAL (volumeChanged (int)), this, TQ_SLOT (volumeChanged (int)));
+    connect (panel->button (KMPlayer::ControlPanel::button_red), TQ_SIGNAL (clicked ()), this, TQ_SLOT (keyRed ()));
+    connect (panel->button (KMPlayer::ControlPanel::button_green), TQ_SIGNAL (clicked ()), this, TQ_SLOT (keyGreen ()));
+    connect (panel->button (KMPlayer::ControlPanel::button_yellow), TQ_SIGNAL (clicked ()), this, TQ_SLOT (keyYellow ()));
+    connect (panel->button (KMPlayer::ControlPanel::button_blue), TQ_SIGNAL (clicked ()), this, TQ_SLOT (keyBlue ()));
     setAspect (m_document, scale ? 16.0/9 : 1.33);
     if (!m_url.protocol ().compare ("kmplayer"))
         m_request_jump = KURL::decode_string (m_url.path ()).mid (1);
     setURL (KURL (TQString ("vdr://localhost:%1").arg (tcp_port)));
-    TQTimer::singleShot (0, m_player, TQT_SLOT (play ()));
+    TQTimer::singleShot (0, m_player, TQ_SLOT (play ()));
 }
 
 KDE_NO_EXPORT void KMPlayerVDRSource::deactivate () {
-    disconnect (m_socket, TQT_SIGNAL (error (int)), this, TQT_SLOT (socketError (int)));
+    disconnect (m_socket, TQ_SIGNAL (error (int)), this, TQ_SLOT (socketError (int)));
     if (m_player->view ()) {
-        disconnect (this, TQT_SIGNAL(startPlaying()), this, TQT_SLOT(processStarted()));
-        disconnect (this, TQT_SIGNAL (stopPlaying()), this, TQT_SLOT(processStopped()));
+        disconnect (this, TQ_SIGNAL(startPlaying()), this, TQ_SLOT(processStarted()));
+        disconnect (this, TQ_SIGNAL (stopPlaying()), this, TQ_SLOT(processStopped()));
         KMPlayer::ControlPanel * panel = m_app->view()->controlPanel ();
-        disconnect (panel->volumeBar (), TQT_SIGNAL (volumeChanged (int)), this, TQT_SLOT (volumeChanged (int)));
-        disconnect (panel->button (KMPlayer::ControlPanel::button_red), TQT_SIGNAL (clicked ()), this, TQT_SLOT (keyRed ()));
-        disconnect (panel->button (KMPlayer::ControlPanel::button_green), TQT_SIGNAL (clicked ()), this, TQT_SLOT (keyGreen ()));
-        disconnect (panel->button (KMPlayer::ControlPanel::button_yellow), TQT_SIGNAL (clicked ()), this, TQT_SLOT (keyYellow ()));
-        disconnect (panel->button (KMPlayer::ControlPanel::button_blue), TQT_SIGNAL (clicked ()), this, TQT_SLOT (keyBlue ()));
+        disconnect (panel->volumeBar (), TQ_SIGNAL (volumeChanged (int)), this, TQ_SLOT (volumeChanged (int)));
+        disconnect (panel->button (KMPlayer::ControlPanel::button_red), TQ_SIGNAL (clicked ()), this, TQ_SLOT (keyRed ()));
+        disconnect (panel->button (KMPlayer::ControlPanel::button_green), TQ_SIGNAL (clicked ()), this, TQ_SLOT (keyGreen ()));
+        disconnect (panel->button (KMPlayer::ControlPanel::button_yellow), TQ_SIGNAL (clicked ()), this, TQ_SLOT (keyYellow ()));
+        disconnect (panel->button (KMPlayer::ControlPanel::button_blue), TQ_SIGNAL (clicked ()), this, TQ_SLOT (keyBlue ()));
     }
     processStopped ();
     m_request_jump.truncate (0);
@@ -240,29 +240,29 @@ KDE_NO_EXPORT void KMPlayerVDRSource::connected () {
     TDEAction * action = m_app->actionCollection ()->action ("vdr_connect");
     action->setIcon (TQString ("connect_no"));
     action->setText (i18n ("Dis&connect"));
-    DEF_ACT (act_up, i18n ("VDR Key Up"), "go-up", , TQT_SLOT (keyUp ()), "vdr_key_up");
-    DEF_ACT (act_down, i18n ("VDR Key Down"), "go-down", , TQT_SLOT (keyDown ()), "vdr_key_down");
-    DEF_ACT (act_back, i18n ("VDR Key Back"), "back", , TQT_SLOT (keyBack ()), "vdr_key_back");
-    DEF_ACT (act_ok, i18n ("VDR Key Ok"), "ok", , TQT_SLOT (keyOk ()), "vdr_key_ok");
-    DEF_ACT (act_setup, i18n ("VDR Key Setup"), "configure", , TQT_SLOT (keySetup ()), "vdr_key_setup");
-    DEF_ACT (act_channels, i18n ("VDR Key Channels"), "player_playlist", , TQT_SLOT (keyChannels ()), "vdr_key_channels");
-    DEF_ACT (act_menu, i18n ("VDR Key Menu"), "showmenu", , TQT_SLOT (keyMenu ()), "vdr_key_menu");
-    DEF_ACT (act_red, i18n ("VDR Key Red"), "red", , TQT_SLOT (keyRed ()), "vdr_key_red");
-    DEF_ACT (act_green, i18n ("VDR Key Green"), "green", , TQT_SLOT (keyGreen ()), "vdr_key_green");
-    DEF_ACT (act_yellow, i18n ("VDR Key Yellow"), "yellow", , TQT_SLOT (keyYellow ()), "vdr_key_yellow");
-    DEF_ACT (act_blue, i18n ("VDR Key Blue"), "blue", , TQT_SLOT (keyBlue ()), "vdr_key_blue");
-    DEF_ACT (act_custom, "VDR Custom Command", "application-x-executable", , TQT_SLOT (customCmd ()), "vdr_key_custom");
+    DEF_ACT (act_up, i18n ("VDR Key Up"), "go-up", , TQ_SLOT (keyUp ()), "vdr_key_up");
+    DEF_ACT (act_down, i18n ("VDR Key Down"), "go-down", , TQ_SLOT (keyDown ()), "vdr_key_down");
+    DEF_ACT (act_back, i18n ("VDR Key Back"), "back", , TQ_SLOT (keyBack ()), "vdr_key_back");
+    DEF_ACT (act_ok, i18n ("VDR Key Ok"), "ok", , TQ_SLOT (keyOk ()), "vdr_key_ok");
+    DEF_ACT (act_setup, i18n ("VDR Key Setup"), "configure", , TQ_SLOT (keySetup ()), "vdr_key_setup");
+    DEF_ACT (act_channels, i18n ("VDR Key Channels"), "player_playlist", , TQ_SLOT (keyChannels ()), "vdr_key_channels");
+    DEF_ACT (act_menu, i18n ("VDR Key Menu"), "showmenu", , TQ_SLOT (keyMenu ()), "vdr_key_menu");
+    DEF_ACT (act_red, i18n ("VDR Key Red"), "red", , TQ_SLOT (keyRed ()), "vdr_key_red");
+    DEF_ACT (act_green, i18n ("VDR Key Green"), "green", , TQ_SLOT (keyGreen ()), "vdr_key_green");
+    DEF_ACT (act_yellow, i18n ("VDR Key Yellow"), "yellow", , TQ_SLOT (keyYellow ()), "vdr_key_yellow");
+    DEF_ACT (act_blue, i18n ("VDR Key Blue"), "blue", , TQ_SLOT (keyBlue ()), "vdr_key_blue");
+    DEF_ACT (act_custom, "VDR Custom Command", "application-x-executable", , TQ_SLOT (customCmd ()), "vdr_key_custom");
     m_app->initMenu (); // update menu and toolbar
-    DEF_ACT (act_0, i18n ("VDR Key 0"), "0", TQt::Key_0, TQT_SLOT (key0 ()), "vdr_key_0");
-    DEF_ACT (act_1, i18n ("VDR Key 1"), "1", TQt::Key_1, TQT_SLOT (key1 ()), "vdr_key_1");
-    DEF_ACT (act_2, i18n ("VDR Key 2"), "2", TQt::Key_2, TQT_SLOT (key2 ()), "vdr_key_2");
-    DEF_ACT (act_3, i18n ("VDR Key 3"), "3", TQt::Key_3, TQT_SLOT (key3 ()), "vdr_key_3");
-    DEF_ACT (act_4, i18n ("VDR Key 4"), "4", TQt::Key_4, TQT_SLOT (key4 ()), "vdr_key_4");
-    DEF_ACT (act_5, i18n ("VDR Key 5"), "5", TQt::Key_5, TQT_SLOT (key5 ()), "vdr_key_5");
-    DEF_ACT (act_6, i18n ("VDR Key 6"), "6", TQt::Key_6, TQT_SLOT (key6 ()), "vdr_key_6");
-    DEF_ACT (act_7, i18n ("VDR Key 7"), "7", TQt::Key_7, TQT_SLOT (key7 ()), "vdr_key_7");
-    DEF_ACT (act_8, i18n ("VDR Key 8"), "8", TQt::Key_8, TQT_SLOT (key8 ()), "vdr_key_8");
-    DEF_ACT (act_9, i18n ("VDR Key 9"), "9", TQt::Key_9, TQT_SLOT (key9 ()), "vdr_key_9");
+    DEF_ACT (act_0, i18n ("VDR Key 0"), "0", TQt::Key_0, TQ_SLOT (key0 ()), "vdr_key_0");
+    DEF_ACT (act_1, i18n ("VDR Key 1"), "1", TQt::Key_1, TQ_SLOT (key1 ()), "vdr_key_1");
+    DEF_ACT (act_2, i18n ("VDR Key 2"), "2", TQt::Key_2, TQ_SLOT (key2 ()), "vdr_key_2");
+    DEF_ACT (act_3, i18n ("VDR Key 3"), "3", TQt::Key_3, TQ_SLOT (key3 ()), "vdr_key_3");
+    DEF_ACT (act_4, i18n ("VDR Key 4"), "4", TQt::Key_4, TQ_SLOT (key4 ()), "vdr_key_4");
+    DEF_ACT (act_5, i18n ("VDR Key 5"), "5", TQt::Key_5, TQ_SLOT (key5 ()), "vdr_key_5");
+    DEF_ACT (act_6, i18n ("VDR Key 6"), "6", TQt::Key_6, TQ_SLOT (key6 ()), "vdr_key_6");
+    DEF_ACT (act_7, i18n ("VDR Key 7"), "7", TQt::Key_7, TQ_SLOT (key7 ()), "vdr_key_7");
+    DEF_ACT (act_8, i18n ("VDR Key 8"), "8", TQt::Key_8, TQ_SLOT (key8 ()), "vdr_key_8");
+    DEF_ACT (act_9, i18n ("VDR Key 9"), "9", TQt::Key_9, TQ_SLOT (key9 ()), "vdr_key_9");
     //KMPlayer::ViewLayer * layer = m_app->view ()->viewArea ();
     for (int i = 0; i < int (act_last); ++i)
         // somehow, the configured shortcuts only show up after createGUI() call
@@ -710,13 +710,13 @@ KDE_NO_EXPORT void KMPlayerVDRSource::sync (bool fromUI) {
                 }
             }
         } else // wait for showEvent
-            connect (xvideo, TQT_SIGNAL (configReceived()), this, TQT_SLOT (configReceived()));
+            connect (xvideo, TQ_SIGNAL (configReceived()), this, TQ_SLOT (configReceived()));
     }
 }
 
 KDE_NO_EXPORT void KMPlayerVDRSource::configReceived () {
     XVideo * xvideo = static_cast<XVideo *>(m_player->players()["xvideo"]);
-    disconnect (xvideo, TQT_SIGNAL (configReceived()), this, TQT_SLOT (configReceived()));
+    disconnect (xvideo, TQ_SIGNAL (configReceived()), this, TQ_SLOT (configReceived()));
     sync (false);
 }
 
