@@ -361,8 +361,8 @@ KDE_NO_EXPORT void View::updateVolume () {
         if (!m_mixer_init) {
             TQLabel * mixer_label = new TQLabel (i18n ("Volume:"), m_control_panel->popupMenu ());
             m_control_panel->popupMenu ()->insertItem (mixer_label, -1, 4);
-            m_volume_slider = new TQSlider (0, 100, 10, volume, Qt::Horizontal, m_control_panel->popupMenu ());
-            connect(m_volume_slider, TQT_SIGNAL(valueChanged(int)), this,TQT_SLOT(setVolume(int)));
+            m_volume_slider = new TQSlider (0, 100, 10, volume, TQt::Horizontal, m_control_panel->popupMenu ());
+            connect(m_volume_slider, TQ_SIGNAL(valueChanged(int)), this,TQ_SLOT(setVolume(int)));
             m_control_panel->popupMenu ()->insertItem (m_volume_slider, ControlPanel::menu_volume, 5);
             m_control_panel->popupMenu ()->insertSeparator (6);
         } else {
@@ -656,7 +656,7 @@ bool View::x11Event (XEvent * e) {
         case MapNotify:
             if (e->xmap.event == m_viewer->embeddedWinId ()) {
                 show ();
-                TQTimer::singleShot (10, m_viewer, TQT_SLOT (sendConfigureEvent ()));
+                TQTimer::singleShot (10, m_viewer, TQ_SLOT (sendConfigureEvent ()));
             }
             break;
         /*case ConfigureNotify:
@@ -733,7 +733,7 @@ KDE_NO_EXPORT void Viewer::windowChanged (WId w) {
 }
 
 KDE_NO_EXPORT void Viewer::mouseMoveEvent (TQMouseEvent * e) {
-    if (e->state () == Qt::NoButton) {
+    if (e->state () == TQt::NoButton) {
         int cp_height = m_view->controlPanel ()->maximumSize ().height ();
         m_view->delayedShowButtons (e->y () > height () - cp_height);
     }
