@@ -89,7 +89,7 @@ private:
  * The view containing ViewArea and playlist
  */
 class KMPLAYER_EXPORT View : public KMediaPlayer::View {
-    Q_OBJECT
+    TQ_OBJECT
   
 public:
     enum ControlPanelMode {
@@ -208,7 +208,7 @@ private:
  * The video widget
  */
 class KMPLAYER_EXPORT Viewer : public QXEmbed {
-    Q_OBJECT
+    TQ_OBJECT
   
 public:
     Viewer(TQWidget *parent, View * view);
