@@ -134,18 +134,18 @@ KDE_NO_CDTOR_EXPORT PlayListView::PlayListView (TQWidget * parent, View * view,
     menu_pix = TDEGlobal::iconLoader ()->loadIcon (TQString ("player_playlist"), TDEIcon::Small);
     config_pix = TDEGlobal::iconLoader ()->loadIcon (TQString ("configure"), TDEIcon::Small);
     url_pix = TDEGlobal::iconLoader ()->loadIcon (TQString ("www"), TDEIcon::Small);
-    m_find = KStdAction::find (TQT_TQOBJECT(this), TQT_SLOT (slotFind ()), ac, "find");
-    m_find_next = KStdAction::findNext (TQT_TQOBJECT(this), TQT_SLOT(slotFindNext()), ac, "next");
+    m_find = KStdAction::find (this, TQ_SLOT (slotFind ()), ac, "find");
+    m_find_next = KStdAction::findNext (this, TQ_SLOT(slotFindNext()), ac, "next");
     m_find_next->setEnabled (false);
-    connect (this, TQT_SIGNAL (contextMenuRequested (TQListViewItem *, const TQPoint &, int)), this, TQT_SLOT (contextMenuItem (TQListViewItem *, const TQPoint &, int)));
-    connect (this, TQT_SIGNAL (expanded (TQListViewItem *)),
-             this, TQT_SLOT (itemExpanded (TQListViewItem *)));
-    connect (this, TQT_SIGNAL (dropped (TQDropEvent *, TQListViewItem *)),
-             this, TQT_SLOT (itemDropped (TQDropEvent *, TQListViewItem *)));
-    connect (this, TQT_SIGNAL (itemRenamed (TQListViewItem *)),
-             this, TQT_SLOT (itemIsRenamed (TQListViewItem *)));
-    connect (this, TQT_SIGNAL (selectionChanged (TQListViewItem *)),
-             this, TQT_SLOT (itemIsSelected (TQListViewItem *)));
+    connect (this, TQ_SIGNAL (contextMenuRequested (TQListViewItem *, const TQPoint &, int)), this, TQ_SLOT (contextMenuItem (TQListViewItem *, const TQPoint &, int)));
+    connect (this, TQ_SIGNAL (expanded (TQListViewItem *)),
+             this, TQ_SLOT (itemExpanded (TQListViewItem *)));
+    connect (this, TQ_SIGNAL (dropped (TQDropEvent *, TQListViewItem *)),
+             this, TQ_SLOT (itemDropped (TQDropEvent *, TQListViewItem *)));
+    connect (this, TQ_SIGNAL (itemRenamed (TQListViewItem *)),
+             this, TQ_SLOT (itemIsRenamed (TQListViewItem *)));
+    connect (this, TQ_SIGNAL (selectionChanged (TQListViewItem *)),
+             this, TQ_SLOT (itemIsSelected (TQListViewItem *)));
 }
 
 KDE_NO_CDTOR_EXPORT PlayListView::~PlayListView () {
@@ -277,7 +277,7 @@ void PlayListView::updateTree (int id, NodePtr root, NodePtr active,
     bool need_timer = !tree_update;
     tree_update = new TreeUpdate (ritem, active, select, open, tree_update);
     if (need_timer)
-        TQTimer::singleShot (0, this, TQT_SLOT (updateTrees ()));
+        TQTimer::singleShot (0, this, TQ_SLOT (updateTrees ()));
 }
 
 KDE_NO_EXPORT void PlayListView::updateTrees () {
@@ -353,7 +353,7 @@ KDE_NO_EXPORT void PlayListView::contextMenuItem (TQListViewItem * vi, const TQP
             m_itemmenu->insertItem (TDEGlobal::iconLoader ()->loadIconSet
                     (TQString ("edit-copy"), TDEIcon::Small, 0, true),
                     i18n ("&Copy to Clipboard"),
-                    this, TQT_SLOT (copyToClipboard ()), 0, 0);
+                    this, TQ_SLOT (copyToClipboard ()), 0, 0);
             if (item->m_attr ||
                     (item->node && (item->node->isPlayable () ||
                                     item->node->isDocument ()) &&
@@ -361,10 +361,10 @@ KDE_NO_EXPORT void PlayListView::contextMenuItem (TQListViewItem * vi, const TQP
                 m_itemmenu->insertItem (TDEGlobal::iconLoader ()->loadIconSet
                         (TQString ("bookmark_add"), TDEIcon::Small, 0, true),
                         i18n ("&Add Bookmark"),
-                        this, TQT_SLOT (addBookMark ()), 0, 1);
+                        this, TQ_SLOT (addBookMark ()), 0, 1);
             if (ritem->have_dark_nodes) {
                 m_itemmenu->insertItem (i18n ("&Show all"),
-                        this, TQT_SLOT (toggleShowAllNodes ()), 0, 2);
+                        this, TQ_SLOT (toggleShowAllNodes ()), 0, 2);
                 m_itemmenu->setItemChecked (2, ritem->show_all_nodes);
             }
             m_itemmenu->insertSeparator ();
@@ -555,7 +555,7 @@ KDE_NO_EXPORT void PlayListView::slotFind () {
     if (!m_find_dialog) {
         m_find_dialog = new KFindDialog (false, this, "kde_kmplayer_find", KFindDialog::CaseSensitive);
         m_find_dialog->setHasSelection (false);
-        connect(m_find_dialog, TQT_SIGNAL(okClicked ()), this, TQT_SLOT(slotFindOk ()));
+        connect(m_find_dialog, TQ_SIGNAL(okClicked ()), this, TQ_SLOT(slotFindOk ()));
     } else
         m_find_dialog->setPattern (TQString ());
     m_find_dialog->show ();
