@@ -132,20 +132,20 @@ KDE_NO_CDTOR_EXPORT Preferences::Preferences(PartBase * player, Settings * setti
         addPrefPage (p);
         
 
-    connect (this, TQT_SIGNAL (defaultClicked ()), TQT_SLOT (confirmDefaults ()));
+    connect (this, TQ_SIGNAL (defaultClicked ()), TQ_SLOT (confirmDefaults ()));
 }
 
 KDE_NO_EXPORT void Preferences::setPage (const char * name) {
-    TQObject * o = child (name, TQFRAME_OBJECT_NAME_STRING);
+    TQObject * o = child (name, "TQFrame");
     if (!o) return;
-    TQFrame * page = static_cast <TQFrame *> (TQT_TQWIDGET(o));
+    TQFrame * page = static_cast <TQFrame *>(o);
     TQWidget * w = page->parentWidget ();
-    while (w && !w->inherits (TQTABWIDGET_OBJECT_NAME_STRING))
+    while (w && !w->inherits ("TQTabWidget"))
         w = w->parentWidget ();
     if (!w) return;
     TQTabWidget * t = static_cast <TQTabWidget*> (w);
     t->setCurrentPage (t->indexOf(page));
-    if (!t->parentWidget() || !t->parentWidget()->inherits (TQFRAME_OBJECT_NAME_STRING))
+    if (!t->parentWidget() || !t->parentWidget()->inherits ("TQFrame"))
         return;
     showPage (pageIndex (t->parentWidget ()));
 }
@@ -189,7 +189,7 @@ KDE_NO_EXPORT void Preferences::removePrefPage(PreferencesPage * page) {
         }
     if (!tab->count ()) {
         TQWidget * w = tab->parentWidget ();
-        while (w && !w->inherits (TQFRAME_OBJECT_NAME_STRING))
+        while (w && !w->inherits ("TQFrame"))
             w = w->parentWidget ();
         delete w;
         entries.erase (en_it);
@@ -204,7 +204,7 @@ KDE_NO_CDTOR_EXPORT PrefGeneralPageGeneral::PrefGeneralPageGeneral(TQWidget *par
 {
     TQVBoxLayout *layout = new TQVBoxLayout(this, 5, 2);
 
-    TQGroupBox *windowbox = new TQGroupBox(1, Qt::Vertical, i18n("Window"), this);
+    TQGroupBox *windowbox = new TQGroupBox(1, TQt::Vertical, i18n("Window"), this);
     TQWidget * wbox = new TQWidget (windowbox);
     TQWidget * bbox = new TQWidget (wbox);
     TQGridLayout * gridlayout = new TQGridLayout (bbox, 2, 2);
@@ -217,14 +217,14 @@ KDE_NO_CDTOR_EXPORT PrefGeneralPageGeneral::PrefGeneralPageGeneral(TQWidget *par
     gridlayout->addWidget (keepSizeRatio, 0, 0);
     gridlayout->addWidget (dockSysTray, 1, 0);
     gridlayout->addWidget (autoResize, 0, 1);
-    sizesChoice = new TQButtonGroup (2, Qt::Vertical, wbox);
+    sizesChoice = new TQButtonGroup (2, TQt::Vertical, wbox);
     new TQRadioButton (i18n("Remember window size on exit"), sizesChoice);
     new TQRadioButton (i18n("Always start with fixed size"), sizesChoice);
     TQVBoxLayout * vbox = new TQVBoxLayout (wbox, 2, 2);
     vbox->addWidget (bbox);
     vbox->addWidget (sizesChoice);
 
-    TQGroupBox *playbox =new TQGroupBox(4, Qt::Vertical,i18n("Playing"),this);
+    TQGroupBox *playbox =new TQGroupBox(4, TQt::Vertical,i18n("Playing"),this);
     loop = new TQCheckBox (i18n("Loop"), playbox);
     TQWhatsThis::add(loop, i18n("Makes current movie loop"));
     framedrop = new TQCheckBox (i18n ("Allow framedrops"), playbox);
@@ -234,7 +234,7 @@ KDE_NO_CDTOR_EXPORT PrefGeneralPageGeneral::PrefGeneralPageGeneral(TQWidget *par
     adjustcolors = new TQCheckBox(i18n("Auto set colors on start"), playbox);
     TQWhatsThis::add (adjustcolors, i18n ("When a movie starts, the colors will be set according the sliders for colors"));
 
-    TQGroupBox * gbox =new TQGroupBox (1, Qt::Vertical, i18n("Control Panel"), this);
+    TQGroupBox * gbox =new TQGroupBox (1, TQt::Vertical, i18n("Control Panel"), this);
     bbox =new TQWidget (gbox);
     //TQGroupBox * bbox = gbox;
     gridlayout = new TQGridLayout (bbox, 3, 2);
@@ -272,29 +272,29 @@ KDE_NO_CDTOR_EXPORT PrefGeneralPageLooks::PrefGeneralPageLooks (TQWidget *parent
    fonts (settings->fonts) {
     TQVBoxLayout *layout = new TQVBoxLayout(this, 5, 2);
 
-    TQGroupBox *colorbox= new TQGroupBox(2, Qt::Horizontal, i18n("Colors"), this);
+    TQGroupBox *colorbox= new TQGroupBox(2, TQt::Horizontal, i18n("Colors"), this);
     colorscombo = new TQComboBox (colorbox);
     for (int i = 0; i < int (ColorSetting::last_target); i++)
         colorscombo->insertItem (colors[i].title);
     colorscombo->setCurrentItem (0);
-    connect (colorscombo, TQT_SIGNAL (activated (int)),
-            this, TQT_SLOT (colorItemChanged(int)));
+    connect (colorscombo, TQ_SIGNAL (activated (int)),
+            this, TQ_SLOT (colorItemChanged(int)));
     colorbutton = new KColorButton (colorbox);
     colorbutton->setColor (colors[0].color);
-    connect (colorbutton, TQT_SIGNAL (changed (const TQColor &)),
-            this, TQT_SLOT (colorCanged (const TQColor &)));
+    connect (colorbutton, TQ_SIGNAL (changed (const TQColor &)),
+            this, TQ_SLOT (colorCanged (const TQColor &)));
 
-    TQGroupBox *fontbox = new TQGroupBox (2,Qt::Horizontal, i18n ("Fonts"), this);
+    TQGroupBox *fontbox = new TQGroupBox (2,TQt::Horizontal, i18n ("Fonts"), this);
     fontscombo = new TQComboBox (fontbox);
     for (int i = 0; i < int (FontSetting::last_target); i++)
         fontscombo->insertItem (fonts[i].title);
     fontscombo->setCurrentItem (0);
-    connect (fontscombo, TQT_SIGNAL (activated (int)),
-            this, TQT_SLOT (fontItemChanged(int)));
+    connect (fontscombo, TQ_SIGNAL (activated (int)),
+            this, TQ_SLOT (fontItemChanged(int)));
     fontbutton = new TQPushButton (i18n ("AaBbCc"), fontbox);
     fontbutton->setFlat (true);
     fontbutton->setFont (fonts[0].font);
-    connect (fontbutton, TQT_SIGNAL (clicked ()), this, TQT_SLOT (fontClicked ()));
+    connect (fontbutton, TQ_SIGNAL (clicked ()), this, TQ_SLOT (fontClicked ()));
 
     layout->addWidget (colorbox);
     layout->addWidget (fontbox);
@@ -365,7 +365,7 @@ KDE_NO_CDTOR_EXPORT PrefSourcePageURL::PrefSourcePageURL (TQWidget *parent)
     gridlayout->addWidget (backendLabel, 0, 0);
     gridlayout->addWidget (backend, 1, 0);
     gridlayout->addMultiCell (new TQSpacerItem (0, 0, TQSizePolicy::Expanding, TQSizePolicy::Minimum), 0, 1, 1, 1);
-    TQGroupBox *cbox = new TQGroupBox(1, Qt::Vertical, i18n("Network bandwidth"), this);
+    TQGroupBox *cbox = new TQGroupBox(1, TQt::Vertical, i18n("Network bandwidth"), this);
     TQWidget * wbox = new TQWidget (cbox);
     TQGridLayout * bitratelayout = new TQGridLayout (wbox, 2, 3, 5);
     prefBitRate = new TQLineEdit (wbox);
@@ -381,10 +381,10 @@ KDE_NO_CDTOR_EXPORT PrefSourcePageURL::PrefSourcePageURL (TQWidget *parent)
     layout->addLayout (gridlayout);
     layout->addWidget (cbox);
     layout->addItem (new TQSpacerItem (0, 0, TQSizePolicy::Minimum, TQSizePolicy::Expanding));
-    connect (urllist, TQT_SIGNAL(textChanged (const TQString &)),
-             this, TQT_SLOT (slotTextChanged (const TQString &)));
-    connect (sub_urllist, TQT_SIGNAL(textChanged (const TQString &)),
-             this, TQT_SLOT (slotTextChanged (const TQString &)));
+    connect (urllist, TQ_SIGNAL(textChanged (const TQString &)),
+             this, TQ_SLOT (slotTextChanged (const TQString &)));
+    connect (sub_urllist, TQ_SIGNAL(textChanged (const TQString &)),
+             this, TQ_SLOT (slotTextChanged (const TQString &)));
 }
 
 KDE_NO_EXPORT void PrefSourcePageURL::slotBrowse () {
@@ -403,18 +403,18 @@ KDE_NO_CDTOR_EXPORT PrefRecordPage::PrefRecordPage (TQWidget *parent, PartBase *
     urllayout->addWidget (urlLabel);
     urllayout->addWidget (url);
     recordButton = new TQPushButton (i18n ("Start &Recording"), this);
-    connect (recordButton, TQT_SIGNAL (clicked ()), this, TQT_SLOT (slotRecord ()));
+    connect (recordButton, TQ_SIGNAL (clicked ()), this, TQ_SLOT (slotRecord ()));
     TQHBoxLayout *buttonlayout = new TQHBoxLayout;
     buttonlayout->addItem (new TQSpacerItem (0, 0, TQSizePolicy::Minimum, TQSizePolicy::Minimum));
     buttonlayout->addWidget (recordButton);
     source = new TQLabel (i18n ("Current source: ") + m_player->source ()->prettyName (), this);
-    recorder = new TQButtonGroup (m_recorders_length, Qt::Vertical, i18n ("Recorder"), this);
+    recorder = new TQButtonGroup (m_recorders_length, TQt::Vertical, i18n ("Recorder"), this);
     for (RecorderPage * p = m_recorders; p; p = p->next)
         new TQRadioButton (p->name (), recorder);
     if (m_player->source ())
         sourceChanged (0L, m_player->source ());
     recorder->setButton(0); // for now
-    replay = new TQButtonGroup (4, Qt::Vertical, i18n ("Auto Playback"), this);
+    replay = new TQButtonGroup (4, TQt::Vertical, i18n ("Auto Playback"), this);
     new TQRadioButton (i18n ("&No"), replay);
     new TQRadioButton (i18n ("&When recording finished"), replay);
     new TQRadioButton (i18n ("A&fter"), replay);
@@ -434,11 +434,9 @@ KDE_NO_CDTOR_EXPORT PrefRecordPage::PrefRecordPage (TQWidget *parent, PartBase *
     layout->addItem (new TQSpacerItem (5, 0, TQSizePolicy::Minimum, TQSizePolicy::Minimum));
     layout->addLayout (buttonlayout);
     layout->addItem (new TQSpacerItem (5, 0, TQSizePolicy::Minimum, TQSizePolicy::Expanding));
-    connect (m_player, TQT_SIGNAL (sourceChanged(KMPlayer::Source*,KMPlayer::Source*)), this, TQT_SLOT (sourceChanged(KMPlayer::Source*,KMPlayer::Source*)));
-#ifdef HAVE_XINE
-    connect (recorder, TQT_SIGNAL (clicked(int)), this, TQT_SLOT(recorderClicked(int)));
-#endif
-    connect (replay, TQT_SIGNAL (clicked (int)), this, TQT_SLOT (replayClicked (int)));
+    connect (m_player, TQ_SIGNAL (sourceChanged(KMPlayer::Source*,KMPlayer::Source*)), this, TQ_SLOT (sourceChanged(KMPlayer::Source*,KMPlayer::Source*)));
+    connect (recorder, TQ_SIGNAL (clicked(int)), this, TQ_SLOT(recorderClicked(int)));
+    connect (replay, TQ_SIGNAL (clicked (int)), this, TQ_SLOT (replayClicked (int)));
 }
 
 KDE_NO_EXPORT void PrefRecordPage::recordingStarted () {
@@ -450,15 +448,15 @@ KDE_NO_EXPORT void PrefRecordPage::recordingStarted () {
 KDE_NO_EXPORT void PrefRecordPage::recordingFinished () {
     recordButton->setText (i18n ("Start Recording"));
     url->setEnabled (true);
-    TQTimer::singleShot (0, m_player, TQT_SLOT(recordingStopped())); // removed from PartBase::setSource because PartBase::recordingStopped calls openURL and that will call PartBase::setSource and TQt doesn't like disconnecting/connecting a signal that is current
+    TQTimer::singleShot (0, m_player, TQ_SLOT(recordingStopped())); // removed from PartBase::setSource because PartBase::recordingStopped calls openURL and that will call PartBase::setSource and TQt doesn't like disconnecting/connecting a signal that is current
 }
 
 KDE_NO_EXPORT void PrefRecordPage::sourceChanged (Source * olds, Source * nws) {
     int id = 0;
     int nr_recs = 0;
     if (olds) {
-        disconnect(nws,TQT_SIGNAL(startRecording()),this, TQT_SLOT(recordingStarted()));
-        disconnect(nws,TQT_SIGNAL(stopRecording()),this, TQT_SLOT(recordingFinished()));
+        disconnect(nws,TQ_SIGNAL(startRecording()),this, TQ_SLOT(recordingStarted()));
+        disconnect(nws,TQ_SIGNAL(stopRecording()),this, TQ_SLOT(recordingFinished()));
     }
     if (nws) {
         for (RecorderPage * p = m_recorders; p; p = p->next, ++id) {
@@ -468,14 +466,19 @@ KDE_NO_EXPORT void PrefRecordPage::sourceChanged (Source * olds, Source * nws) {
             if (b) nr_recs++;
         }
         source->setText (i18n ("Current Source: ") + nws->prettyName ());
-        connect (nws, TQT_SIGNAL(startRecording()), this, TQT_SLOT(recordingStarted()));
-        connect (nws, TQT_SIGNAL(stopRecording()), this, TQT_SLOT(recordingFinished()));
+        connect (nws, TQ_SIGNAL(startRecording()), this, TQ_SLOT(recordingStarted()));
+        connect (nws, TQ_SIGNAL(stopRecording()), this, TQ_SLOT(recordingFinished()));
     }
     recordButton->setEnabled (nr_recs > 0);
 }
 
 KDE_NO_EXPORT void PrefRecordPage::recorderClicked (int id) {
-    bool b = recorder->find(id)->text().find (TQString::fromLatin1("Xine")) > -1;
+    bool b = false;
+    TQButton *recBtn = recorder->find(id);
+    if (recBtn)
+    {
+       b = recBtn->text().find (TQString::fromLatin1("Xine")) > -1;
+    }
     replay->setEnabled (!b);
     if (b)
         replay->setButton (Settings::ReplayNo);
@@ -487,8 +490,8 @@ KDE_NO_EXPORT void PrefRecordPage::replayClicked (int id) {
 }
 
 KDE_NO_EXPORT void PrefRecordPage::slotRecord () {
-    connect (m_player->source (), TQT_SIGNAL (stopPlaying ()),
-             this, TQT_SLOT (playingStopped ()));
+    connect (m_player->source (), TQ_SIGNAL (stopPlaying ()),
+             this, TQ_SLOT (playingStopped ()));
     if (m_player->process () && m_player->process ()->playing ())
         m_player->process ()->quit ();
     else
@@ -496,8 +499,8 @@ KDE_NO_EXPORT void PrefRecordPage::slotRecord () {
 }
 
 KDE_NO_EXPORT void PrefRecordPage::playingStopped () {
-    disconnect (m_player->source (), TQT_SIGNAL (stopPlaying ()),
-                this, TQT_SLOT (playingStopped ()));
+    disconnect (m_player->source (), TQ_SIGNAL (stopPlaying ()),
+                this, TQ_SLOT (playingStopped ()));
     if (!url->lineEdit()->text().isEmpty()) {
         m_player->settings ()->recordfile = url->lineEdit()->text();
         m_player->settings ()->replaytime = replaytime->text ().toInt ();
@@ -539,7 +542,7 @@ KDE_NO_EXPORT void RecorderPage::record () {
 
 KDE_NO_CDTOR_EXPORT PrefMEncoderPage::PrefMEncoderPage (TQWidget *parent, PartBase * player) : RecorderPage (parent, player) {
     TQVBoxLayout *layout = new TQVBoxLayout (this, 5, 5);
-    format = new TQButtonGroup (3, Qt::Vertical, i18n ("Format"), this);
+    format = new TQButtonGroup (3, TQt::Vertical, i18n ("Format"), this);
     new TQRadioButton (i18n ("Same as source"), format);
     new TQRadioButton (i18n ("Custom"), format);
     TQWidget * customopts = new TQWidget (format);
@@ -550,7 +553,7 @@ KDE_NO_CDTOR_EXPORT PrefMEncoderPage::PrefMEncoderPage (TQWidget *parent, PartBa
     gridlayout->addWidget (arguments, 0, 1);
     layout->addWidget (format);
     layout->addItem (new TQSpacerItem (0, 0, TQSizePolicy::Minimum, TQSizePolicy::Expanding));
-    connect (format, TQT_SIGNAL (clicked (int)), this, TQT_SLOT (formatClicked (int)));
+    connect (format, TQ_SIGNAL (clicked (int)), this, TQ_SLOT (formatClicked (int)));
 }
 
 KDE_NO_EXPORT void PrefMEncoderPage::formatClicked (int id) {
@@ -656,7 +659,7 @@ KDE_NO_CDTOR_EXPORT PrefOPPagePostProc::PrefOPPagePostProc(TQWidget *parent) : T
     TQWidget *presetSelectionWidget = new TQWidget( PostprocessingOptions, "presetSelectionWidget" );
     TQGridLayout *presetSelectionWidgetLayout = new TQGridLayout( presetSelectionWidget, 1, 1, 1);
 
-    TQButtonGroup *presetSelection = new TQButtonGroup(3, Qt::Vertical, presetSelectionWidget);
+    TQButtonGroup *presetSelection = new TQButtonGroup(3, TQt::Vertical, presetSelectionWidget);
     presetSelection->setInsideSpacing(KDialog::spacingHint());
 
     defaultPreset = new TQRadioButton (i18n ("Default"), presetSelection);
@@ -680,7 +683,7 @@ KDE_NO_CDTOR_EXPORT PrefOPPagePostProc::PrefOPPagePostProc(TQWidget *parent) : T
     TQWidget *customFiltersWidget = new TQWidget( PostprocessingOptions, "customFiltersWidget" );
     TQVBoxLayout *customFiltersWidgetLayout = new TQVBoxLayout( customFiltersWidget );
 
-    TQGroupBox *customFilters = new TQGroupBox(0, Qt::Vertical, customFiltersWidget, "customFilters" );
+    TQGroupBox *customFilters = new TQGroupBox(0, TQt::Vertical, customFiltersWidget, "customFilters" );
     customFilters->setSizePolicy(TQSizePolicy((TQSizePolicy::SizeType)1, (TQSizePolicy::SizeType)2));
     customFilters->setFlat(false);
     customFilters->setEnabled( false );
@@ -782,7 +785,7 @@ KDE_NO_CDTOR_EXPORT PrefOPPagePostProc::PrefOPPagePostProc(TQWidget *parent) : T
     //
     TQWidget *deintSelectionWidget = new TQWidget( PostprocessingOptions, "deintSelectionWidget" );
     TQVBoxLayout *deintSelectionWidgetLayout = new TQVBoxLayout( deintSelectionWidget);
-    TQButtonGroup *deinterlacingGroup = new TQButtonGroup(5, Qt::Vertical, deintSelectionWidget, "deinterlacingGroup" );
+    TQButtonGroup *deinterlacingGroup = new TQButtonGroup(5, TQt::Vertical, deintSelectionWidget, "deinterlacingGroup" );
 
     LinBlendDeinterlacer = new TQCheckBox (i18n ("Linear blend deinterlacer"), deinterlacingGroup);
     LinIntDeinterlacer = new TQCheckBox (i18n ("Linear interpolating deinterlacer"), deinterlacingGroup);
@@ -803,17 +806,17 @@ KDE_NO_CDTOR_EXPORT PrefOPPagePostProc::PrefOPPagePostProc(TQWidget *parent) : T
     tabLayout->addWidget( PostprocessingOptions/*, 1, 0*/ );
 
     PostprocessingOptions->setEnabled(false);
-    connect( customPreset, TQT_SIGNAL (toggled(bool) ), customFilters, TQT_SLOT(setEnabled(bool)));
-    connect( postProcessing, TQT_SIGNAL( toggled(bool) ), PostprocessingOptions, TQT_SLOT( setEnabled(bool) ) );
-    connect( HzDeblockFilter, TQT_SIGNAL( toggled(bool) ), HzDeblockAQuality, TQT_SLOT( setEnabled(bool) ) );
-    connect( HzDeblockFilter, TQT_SIGNAL( toggled(bool) ), HzDeblockCFiltering, TQT_SLOT( setEnabled(bool) ) );
-    connect( VtDeblockFilter, TQT_SIGNAL( toggled(bool) ), VtDeblockCFiltering, TQT_SLOT( setEnabled(bool) ) );
-    connect( VtDeblockFilter, TQT_SIGNAL( toggled(bool) ), VtDeblockAQuality, TQT_SLOT( setEnabled(bool) ) );
-    connect( DeringFilter, TQT_SIGNAL( toggled(bool) ), DeringAQuality, TQT_SLOT( setEnabled(bool) ) );
-    connect( DeringFilter, TQT_SIGNAL( toggled(bool) ), DeringCFiltering, TQT_SLOT( setEnabled(bool) ) );
-    //connect( TmpNoiseFilter, TQT_SIGNAL( toggled(bool) ), TmpNoiseSlider, TQT_SLOT( setEnabled(bool) ) );
+    connect( customPreset, TQ_SIGNAL (toggled(bool) ), customFilters, TQ_SLOT(setEnabled(bool)));
+    connect( postProcessing, TQ_SIGNAL( toggled(bool) ), PostprocessingOptions, TQ_SLOT( setEnabled(bool) ) );
+    connect( HzDeblockFilter, TQ_SIGNAL( toggled(bool) ), HzDeblockAQuality, TQ_SLOT( setEnabled(bool) ) );
+    connect( HzDeblockFilter, TQ_SIGNAL( toggled(bool) ), HzDeblockCFiltering, TQ_SLOT( setEnabled(bool) ) );
+    connect( VtDeblockFilter, TQ_SIGNAL( toggled(bool) ), VtDeblockCFiltering, TQ_SLOT( setEnabled(bool) ) );
+    connect( VtDeblockFilter, TQ_SIGNAL( toggled(bool) ), VtDeblockAQuality, TQ_SLOT( setEnabled(bool) ) );
+    connect( DeringFilter, TQ_SIGNAL( toggled(bool) ), DeringAQuality, TQ_SLOT( setEnabled(bool) ) );
+    connect( DeringFilter, TQ_SIGNAL( toggled(bool) ), DeringCFiltering, TQ_SLOT( setEnabled(bool) ) );
+    //connect( TmpNoiseFilter, TQ_SIGNAL( toggled(bool) ), TmpNoiseSlider, TQ_SLOT( setEnabled(bool) ) );
 
-    connect( AutolevelsFilter, TQT_SIGNAL( toggled(bool) ), AutolevelsFullrange, TQT_SLOT( setEnabled(bool) ) );
+    connect( AutolevelsFilter, TQ_SIGNAL( toggled(bool) ), AutolevelsFullrange, TQ_SLOT( setEnabled(bool) ) );
 
     TQWhatsThis::add( defaultPreset, i18n( "Enable mplayer's default postprocessing filters" ) );
     TQWhatsThis::add( customPreset, i18n( "Enable custom postprocessing filters (See: Custom preset -tab)" ) );
