@@ -1245,7 +1245,7 @@ static void followLink (SMIL::LinkingBase * link) {
 
 KDE_NO_EXPORT void MouseVisitor::visit (SMIL::Anchor * anchor) {
     if (event == event_pointer_moved)
-        cursor.setShape (Qt::PointingHandCursor);
+        cursor.setShape (TQt::PointingHandCursor);
     else if (event == event_pointer_clicked)
         followLink (anchor);
 }
@@ -1276,7 +1276,7 @@ KDE_NO_EXPORT void MouseVisitor::visit (SMIL::Area * area) {
                 }
             }
             if (event == event_pointer_moved)
-                cursor.setShape (Qt::PointingHandCursor);
+                cursor.setShape (TQt::PointingHandCursor);
             else {
                 NodeRefListPtr nl = area->listeners (event);
                 if (nl)
@@ -1353,7 +1353,7 @@ KDE_NO_CDTOR_EXPORT ViewArea::ViewArea (TQWidget * parent, View * view)
    m_minimal (false) {
     setEraseColor (TQColor (0, 0, 0));
     setAcceptDrops (true);
-    new TDEAction (i18n ("Fullscreen"), TDEShortcut (TQt::Key_F), TQT_TQOBJECT(this), TQT_SLOT (accelActivated ()), m_collection, "view_fullscreen_toggle");
+    new TDEAction (i18n ("Fullscreen"), TDEShortcut (TQt::Key_F), this, TQ_SLOT (accelActivated ()), m_collection, "view_fullscreen_toggle");
     setMouseTracking (true);
     if (!image_data_map)
         imageCacheDeleter.setObject (image_data_map, new ImageDataMap);
@@ -1363,7 +1363,7 @@ KDE_NO_CDTOR_EXPORT ViewArea::~ViewArea () {
 }
 
 KDE_NO_EXPORT void ViewArea::fullScreen () {
-    TQT_TQOBJECT(this)->killTimers ();
+    this->killTimers ();
     m_mouse_invisible_timer = m_repaint_timer = 0;
     if (m_fullscreen) {
         showNormal ();
@@ -1386,8 +1386,8 @@ KDE_NO_EXPORT void ViewArea::fullScreen () {
         TQPopupMenu * menu = m_view->controlPanel ()->popupMenu ();
         TQLabel * lbl = new TQLabel (i18n ("Scale:"), menu);
         scale_lbl_id = menu->insertItem (lbl, -1, 4);
-        TQSlider * slider = new TQSlider (50, 150, 10, m_fullscreen_scale, Qt::Horizontal, menu);
-        connect (slider, TQT_SIGNAL (valueChanged (int)), this, TQT_SLOT (scale (int)));
+        TQSlider * slider = new TQSlider (50, 150, 10, m_fullscreen_scale, TQt::Horizontal, menu);
+        connect (slider, TQ_SIGNAL (valueChanged (int)), this, TQ_SLOT (scale (int)));
         scale_slider_id = menu->insertItem (slider, -1, 5);
         m_view->controlPanel ()->button (ControlPanel::button_playlist)->setIconSet (TQIconSet (TQPixmap (normal_window_xpm)));
     }
@@ -1413,7 +1413,7 @@ KDE_NO_EXPORT void ViewArea::fullScreen () {
 
 void ViewArea::minimalMode () {
     m_minimal = !m_minimal;
-    TQT_TQOBJECT(this)->killTimers ();
+    this->killTimers ();
     m_mouse_invisible_timer = m_repaint_timer = 0;
     if (m_minimal) {
         m_view->setViewOnly ();
@@ -1445,7 +1445,7 @@ KDE_NO_EXPORT void ViewArea::mouseDoubleClickEvent (TQMouseEvent *) {
 }
 
 KDE_NO_EXPORT void ViewArea::mouseMoveEvent (TQMouseEvent * e) {
-    if (e->state () == Qt::NoButton) {
+    if (e->state () == TQt::NoButton) {
         int vert_buttons_pos = height () - m_view->statusBarHeight ();
         int cp_height = m_view->controlPanel ()->maximumSize ().height ();
         m_view->delayedShowButtons (e->y() > vert_buttons_pos-cp_height &&
